# openapi-client
No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)

This Python package is automatically generated by the [OpenAPI Generator](https://openapi-generator.tech) project:

- API version: 0.1.0
- Package version: 1.0.0
- Build package: org.openapitools.codegen.languages.PythonClientCodegen

## Requirements.

Python 2.7 and 3.4+

## Installation & Usage
### pip install

If the python package is hosted on a repository, you can install directly using:

```sh
pip install git+https://github.com/GIT_USER_ID/GIT_REPO_ID.git
```
(you may need to run `pip` with root permission: `sudo pip install git+https://github.com/GIT_USER_ID/GIT_REPO_ID.git`)

Then import the package:
```python
import openapi_client
```

### Setuptools

Install via [Setuptools](http://pypi.python.org/pypi/setuptools).

```sh
python setup.py install --user
```
(or `sudo python setup.py install` to install the package for all users)

Then import the package:
```python
import openapi_client
```

## Getting Started

Please follow the [installation procedure](#installation--usage) and then run the following:

```python
from __future__ import print_function
import time
import openapi_client
from openapi_client.rest import ApiException
from pprint import pprint


# Defining host is optional and default to http://localhost
configuration.host = "http://localhost"
# Enter a context with an instance of the API client
with openapi_client.ApiClient(configuration) as api_client:
    # Create an instance of the API class
    api_instance = openapi_client.CustomerOffboardingApi(api_client)
    organization_id = 'organization_id_example' # str | 

    try:
        # Deactivate Organization
        api_instance.deactivate_organization_api_v2_organizations_organization_id_deactivate_post(organization_id)
    except ApiException as e:
        print("Exception when calling CustomerOffboardingApi->deactivate_organization_api_v2_organizations_organization_id_deactivate_post: %s\n" % e)
    
```

## Documentation for API Endpoints

All URIs are relative to *http://localhost*

Class | Method | HTTP request | Description
------------ | ------------- | ------------- | -------------
*CustomerOffboardingApi* | [**deactivate_organization_api_v2_organizations_organization_id_deactivate_post**](docs/CustomerOffboardingApi.md#deactivate_organization_api_v2_organizations_organization_id_deactivate_post) | **POST** /api/v2/organizations/{organization_id}/deactivate | Deactivate Organization
*CustomerOffboardingApi* | [**redact_organization_data_api_v2_admin_organization_organization_id_redact_post**](docs/CustomerOffboardingApi.md#redact_organization_data_api_v2_admin_organization_organization_id_redact_post) | **POST** /api/v2/admin/organization/{organization_id}/redact | Redact Organization Data
*DefaultApi* | [**add_cloud_resource_api_v2_clouds_cloud_id_add_resource_put**](docs/DefaultApi.md#add_cloud_resource_api_v2_clouds_cloud_id_add_resource_put) | **PUT** /api/v2/clouds/{cloud_id}/add_resource | Add Cloud Resource
*DefaultApi* | [**add_to_waitlist_api_v2_aioa_cloud_waitlist_post**](docs/DefaultApi.md#add_to_waitlist_api_v2_aioa_cloud_waitlist_post) | **POST** /api/v2/aioa_cloud_waitlist/ | Add To Waitlist
*DefaultApi* | [**admin_batch_create_users_api_v2_users_admin_batch_create_post**](docs/DefaultApi.md#admin_batch_create_users_api_v2_users_admin_batch_create_post) | **POST** /api/v2/users/admin_batch_create | Admin Batch Create Users
*DefaultApi* | [**admission_api_v2_kubernetes_manager_admission_cloud_resource_id_post**](docs/DefaultApi.md#admission_api_v2_kubernetes_manager_admission_cloud_resource_id_post) | **POST** /api/v2/kubernetes_manager/admission/{cloud_resource_id} | Admission
*DefaultApi* | [**alter_cloud_collaborator_api_v2_clouds_cloud_id_collaborators_users_identity_id_put**](docs/DefaultApi.md#alter_cloud_collaborator_api_v2_clouds_cloud_id_collaborators_users_identity_id_put) | **PUT** /api/v2/clouds/{cloud_id}/collaborators/users/{identity_id} | Alter Cloud Collaborator
*DefaultApi* | [**alter_organization_collaborator_api_v2_organization_collaborators_identity_id_put**](docs/DefaultApi.md#alter_organization_collaborator_api_v2_organization_collaborators_identity_id_put) | **PUT** /api/v2/organization_collaborators/{identity_id} | Alter Organization Collaborator
*DefaultApi* | [**alter_project_collaborator_api_v2_projects_project_id_collaborators_role_or_identity_id_put**](docs/DefaultApi.md#alter_project_collaborator_api_v2_projects_project_id_collaborators_role_or_identity_id_put) | **PUT** /api/v2/projects/{project_id}/collaborators/{role_or_identity_id} | Alter Project Collaborator
*DefaultApi* | [**apply_autoscaling_config_update_api_v2_services_v2_service_id_apply_autoscaling_config_update_put**](docs/DefaultApi.md#apply_autoscaling_config_update_api_v2_services_v2_service_id_apply_autoscaling_config_update_put) | **PUT** /api/v2/services-v2/{service_id}/apply_autoscaling_config_update | Apply Autoscaling Config Update
*DefaultApi* | [**apply_service_api_v2_services_v2_apply_put**](docs/DefaultApi.md#apply_service_api_v2_services_v2_apply_put) | **PUT** /api/v2/services-v2/apply | Apply Service
*DefaultApi* | [**apply_service_multi_version_api_v2_services_v2_apply_multi_version_put**](docs/DefaultApi.md#apply_service_multi_version_api_v2_services_v2_apply_multi_version_put) | **PUT** /api/v2/services-v2/apply_multi_version | Apply Service Multi Version
*DefaultApi* | [**archive_cluster_environment_api_v2_application_templates_application_template_id_archive_post**](docs/DefaultApi.md#archive_cluster_environment_api_v2_application_templates_application_template_id_archive_post) | **POST** /api/v2/application_templates/{application_template_id}/archive | Archive Cluster Environment
*DefaultApi* | [**archive_compute_template_api_v2_compute_templates_compute_template_id_archive_post**](docs/DefaultApi.md#archive_compute_template_api_v2_compute_templates_compute_template_id_archive_post) | **POST** /api/v2/compute_templates/{compute_template_id}/archive | Archive Compute Template
*DefaultApi* | [**archive_job_api_v2_decorated_ha_jobs_production_job_id_archive_post**](docs/DefaultApi.md#archive_job_api_v2_decorated_ha_jobs_production_job_id_archive_post) | **POST** /api/v2/decorated_ha_jobs/{production_job_id}/archive | Archive Job
*DefaultApi* | [**archive_job_queue_api_v2_job_queues_job_queue_id_archive_post**](docs/DefaultApi.md#archive_job_queue_api_v2_job_queues_job_queue_id_archive_post) | **POST** /api/v2/job_queues/{job_queue_id}/archive | Archive Job Queue
*DefaultApi* | [**archive_service_api_v2_services_v2_service_id_archive_post**](docs/DefaultApi.md#archive_service_api_v2_services_v2_service_id_archive_post) | **POST** /api/v2/services-v2/{service_id}/archive | Archive Service
*DefaultApi* | [**attach_machine_pool_to_cloud_api_v2_machine_pools_attach_post**](docs/DefaultApi.md#attach_machine_pool_to_cloud_api_v2_machine_pools_attach_post) | **POST** /api/v2/machine_pools/attach | Attach Machine Pool To Cloud
*DefaultApi* | [**aws_marketplace_registration_api_v2_organization_billing_aws_marketplace_registration_post**](docs/DefaultApi.md#aws_marketplace_registration_api_v2_organization_billing_aws_marketplace_registration_post) | **POST** /api/v2/organization_billing/aws_marketplace_registration | Aws Marketplace Registration
*DefaultApi* | [**batch_create_cloud_collaborators_api_v2_clouds_cloud_id_collaborators_users_batch_create_post**](docs/DefaultApi.md#batch_create_cloud_collaborators_api_v2_clouds_cloud_id_collaborators_users_batch_create_post) | **POST** /api/v2/clouds/{cloud_id}/collaborators/users/batch_create | Batch Create Cloud Collaborators
*DefaultApi* | [**batch_create_invitations_api_v2_organization_invitations_batch_create_post**](docs/DefaultApi.md#batch_create_invitations_api_v2_organization_invitations_batch_create_post) | **POST** /api/v2/organization_invitations/batch_create | Batch Create Invitations
*DefaultApi* | [**batch_create_project_collaborators_api_v2_projects_project_id_collaborators_users_batch_create_post**](docs/DefaultApi.md#batch_create_project_collaborators_api_v2_projects_project_id_collaborators_users_batch_create_post) | **POST** /api/v2/projects/{project_id}/collaborators/users/batch_create | Batch Create Project Collaborators
*DefaultApi* | [**batch_get_job_api_v2_decorated_ha_jobs_batch_get_post**](docs/DefaultApi.md#batch_get_job_api_v2_decorated_ha_jobs_batch_get_post) | **POST** /api/v2/decorated_ha_jobs/batch_get | Batch Get Job
*DefaultApi* | [**change_password_api_v2_users_change_password_post**](docs/DefaultApi.md#change_password_api_v2_users_change_password_post) | **POST** /api/v2/users/change_password | Change Password
*DefaultApi* | [**check_is_feature_flag_on_api_v2_userinfo_check_is_feature_flag_on_get**](docs/DefaultApi.md#check_is_feature_flag_on_api_v2_userinfo_check_is_feature_flag_on_get) | **GET** /api/v2/userinfo/check_is_feature_flag_on | Check Is Feature Flag On
*DefaultApi* | [**check_one_time_password_api_v2_users_request_otp_token_otp_get**](docs/DefaultApi.md#check_one_time_password_api_v2_users_request_otp_token_otp_get) | **GET** /api/v2/users/request_otp_token/{otp} | Check One Time Password
*DefaultApi* | [**check_permission_api_v2_authorization_check_post**](docs/DefaultApi.md#check_permission_api_v2_authorization_check_post) | **POST** /api/v2/authorization/check | Check Permission
*DefaultApi* | [**check_waitlist_status_api_v2_aioa_cloud_waitlist_check_status_get**](docs/DefaultApi.md#check_waitlist_status_api_v2_aioa_cloud_waitlist_check_status_get) | **GET** /api/v2/aioa_cloud_waitlist/check_status | Check Waitlist Status
*DefaultApi* | [**clean_grafana_dashboards_api_v2_clouds_cloud_id_clean_grafana_dashboards_post**](docs/DefaultApi.md#clean_grafana_dashboards_api_v2_clouds_cloud_id_clean_grafana_dashboards_post) | **POST** /api/v2/clouds/{cloud_id}/clean-grafana-dashboards | Clean Grafana Dashboards
*DefaultApi* | [**cli_api_v2_machines_cli_get**](docs/DefaultApi.md#cli_api_v2_machines_cli_get) | **GET** /api/v2/machines/cli | Cli
*DefaultApi* | [**clone_workspace_api_v2_experimental_workspaces_from_workspace_post**](docs/DefaultApi.md#clone_workspace_api_v2_experimental_workspaces_from_workspace_post) | **POST** /api/v2/experimental_workspaces/from_workspace | Clone Workspace
*DefaultApi* | [**create_api_key_api_v2_users_create_api_key_post**](docs/DefaultApi.md#create_api_key_api_v2_users_create_api_key_post) | **POST** /api/v2/users/create_api_key | Create Api Key
*DefaultApi* | [**create_application_template_api_v2_application_templates_post**](docs/DefaultApi.md#create_application_template_api_v2_application_templates_post) | **POST** /api/v2/application_templates/ | Create Application Template
*DefaultApi* | [**create_bug_report_api_v2_machines_create_bug_report_post**](docs/DefaultApi.md#create_bug_report_api_v2_machines_create_bug_report_post) | **POST** /api/v2/machines/create_bug_report | Create Bug Report
*DefaultApi* | [**create_build_api_v2_builds_post**](docs/DefaultApi.md#create_build_api_v2_builds_post) | **POST** /api/v2/builds/ | Create Build
*DefaultApi* | [**create_byod_build_api_v2_builds_byod_post**](docs/DefaultApi.md#create_byod_build_api_v2_builds_byod_post) | **POST** /api/v2/builds/byod | Create Byod Build
*DefaultApi* | [**create_byod_cluster_environment_api_v2_application_templates_byod_post**](docs/DefaultApi.md#create_byod_cluster_environment_api_v2_application_templates_byod_post) | **POST** /api/v2/application_templates/byod | Create Byod Cluster Environment
*DefaultApi* | [**create_cloud_api_v2_clouds_post**](docs/DefaultApi.md#create_cloud_api_v2_clouds_post) | **POST** /api/v2/clouds/ | Create Cloud
*DefaultApi* | [**create_cloud_collaborator_api_v2_clouds_cloud_id_collaborators_users_post**](docs/DefaultApi.md#create_cloud_collaborator_api_v2_clouds_cloud_id_collaborators_users_post) | **POST** /api/v2/clouds/{cloud_id}/collaborators/users | Create Cloud Collaborator
*DefaultApi* | [**create_cloud_collaborator_api_v2_projects_project_id_collaborators_cloud_post**](docs/DefaultApi.md#create_cloud_collaborator_api_v2_projects_project_id_collaborators_cloud_post) | **POST** /api/v2/projects/{project_id}/collaborators/cloud | Create Cloud Collaborator
*DefaultApi* | [**create_compute_template_api_v2_compute_templates_post**](docs/DefaultApi.md#create_compute_template_api_v2_compute_templates_post) | **POST** /api/v2/compute_templates/ | Create Compute Template
*DefaultApi* | [**create_configuration_api_v2_organization_configurations_post**](docs/DefaultApi.md#create_configuration_api_v2_organization_configurations_post) | **POST** /api/v2/organization_configurations/ | Create Configuration
*DefaultApi* | [**create_configuration_script_api_v2_organization_configurations_create_helper_get**](docs/DefaultApi.md#create_configuration_script_api_v2_organization_configurations_create_helper_get) | **GET** /api/v2/organization_configurations/create_helper | Create Configuration Script
*DefaultApi* | [**create_dataset_upload_api_v2_datasets_upload_post**](docs/DefaultApi.md#create_dataset_upload_api_v2_datasets_upload_post) | **POST** /api/v2/datasets/upload | Create Dataset Upload
*DefaultApi* | [**create_instance_usage_budget_api_v2_instance_usage_budgets_post**](docs/DefaultApi.md#create_instance_usage_budget_api_v2_instance_usage_budgets_post) | **POST** /api/v2/instance_usage_budgets/ | Create Instance Usage Budget
*DefaultApi* | [**create_invitation_api_v2_organization_invitations_post**](docs/DefaultApi.md#create_invitation_api_v2_organization_invitations_post) | **POST** /api/v2/organization_invitations/ | Create Invitation
*DefaultApi* | [**create_job_api_v2_decorated_ha_jobs_create_post**](docs/DefaultApi.md#create_job_api_v2_decorated_ha_jobs_create_post) | **POST** /api/v2/decorated_ha_jobs/create | Create Job
*DefaultApi* | [**create_job_queue_api_v2_job_queues_create_post**](docs/DefaultApi.md#create_job_queue_api_v2_job_queues_create_post) | **POST** /api/v2/job_queues/create | Create Job Queue
*DefaultApi* | [**create_machine_api_v2_machines_create_post**](docs/DefaultApi.md#create_machine_api_v2_machines_create_post) | **POST** /api/v2/machines/create | Create Machine
*DefaultApi* | [**create_machine_pool_api_v2_machine_pools_create_post**](docs/DefaultApi.md#create_machine_pool_api_v2_machine_pools_create_post) | **POST** /api/v2/machine_pools/create | Create Machine Pool
*DefaultApi* | [**create_one_time_password_api_v2_users_create_otp_token_get**](docs/DefaultApi.md#create_one_time_password_api_v2_users_create_otp_token_get) | **GET** /api/v2/users/create_otp_token | Create One Time Password
*DefaultApi* | [**create_or_update_job_api_v2_experimental_cron_jobs_put**](docs/DefaultApi.md#create_or_update_job_api_v2_experimental_cron_jobs_put) | **PUT** /api/v2/experimental_cron_jobs/ | Create Or Update Job
*DefaultApi* | [**create_or_update_metronome_customer_info_api_v2_metronome_customer_info_post**](docs/DefaultApi.md#create_or_update_metronome_customer_info_api_v2_metronome_customer_info_post) | **POST** /api/v2/metronome_customer_info/ | Create Or Update Metronome Customer Info
*DefaultApi* | [**create_project_api_v2_projects_post**](docs/DefaultApi.md#create_project_api_v2_projects_post) | **POST** /api/v2/projects/ | Create Project
*DefaultApi* | [**create_project_collaborator_api_v2_projects_project_id_collaborators_users_post**](docs/DefaultApi.md#create_project_collaborator_api_v2_projects_project_id_collaborators_users_post) | **POST** /api/v2/projects/{project_id}/collaborators/users | Create Project Collaborator
*DefaultApi* | [**create_resource_notification_api_v2_resource_notifications_post**](docs/DefaultApi.md#create_resource_notification_api_v2_resource_notifications_post) | **POST** /api/v2/resource_notifications/ | Create Resource Notification
*DefaultApi* | [**create_resource_quota_api_v2_resource_quotas_post**](docs/DefaultApi.md#create_resource_quota_api_v2_resource_quotas_post) | **POST** /api/v2/resource_quotas/ | Create Resource Quota
*DefaultApi* | [**create_service_account_api_v2_users_service_accounts_post**](docs/DefaultApi.md#create_service_account_api_v2_users_service_accounts_post) | **POST** /api/v2/users/service_accounts | Create Service Account
*DefaultApi* | [**create_session_command_api_v2_sessions_session_id_create_session_command_post**](docs/DefaultApi.md#create_session_command_api_v2_sessions_session_id_create_session_command_post) | **POST** /api/v2/sessions/{session_id}/create_session_command | Create Session Command
*DefaultApi* | [**create_template_api_v2_workspace_templates_post**](docs/DefaultApi.md#create_template_api_v2_workspace_templates_post) | **POST** /api/v2/workspace_templates/ | Create Template
*DefaultApi* | [**create_version_api_v2_workspace_templates_template_id_versions_post**](docs/DefaultApi.md#create_version_api_v2_workspace_templates_template_id_versions_post) | **POST** /api/v2/workspace_templates/{template_id}/versions | Create Version
*DefaultApi* | [**create_workspace_api_v2_experimental_workspaces_post**](docs/DefaultApi.md#create_workspace_api_v2_experimental_workspaces_post) | **POST** /api/v2/experimental_workspaces/ | Create Workspace
*DefaultApi* | [**create_workspace_from_template_api_v2_experimental_workspaces_from_template_post**](docs/DefaultApi.md#create_workspace_from_template_api_v2_experimental_workspaces_from_template_post) | **POST** /api/v2/experimental_workspaces/from_template | Create Workspace From Template
*DefaultApi* | [**delete_cloud_api_v2_clouds_cloud_id_delete**](docs/DefaultApi.md#delete_cloud_api_v2_clouds_cloud_id_delete) | **DELETE** /api/v2/clouds/{cloud_id} | Delete Cloud
*DefaultApi* | [**delete_cloud_collaborator_api_v2_clouds_cloud_id_collaborators_identity_id_delete**](docs/DefaultApi.md#delete_cloud_collaborator_api_v2_clouds_cloud_id_collaborators_identity_id_delete) | **DELETE** /api/v2/clouds/{cloud_id}/collaborators/{identity_id} | Delete Cloud Collaborator
*DefaultApi* | [**delete_databricks_connection_api_v2_integrations_connections_databricks_connection_id_delete**](docs/DefaultApi.md#delete_databricks_connection_api_v2_integrations_connections_databricks_connection_id_delete) | **DELETE** /api/v2/integrations/connections/databricks/{connection_id} | Delete Databricks Connection
*DefaultApi* | [**delete_hosted_cloud_api_v2_clouds_hosted_cloud_id_delete**](docs/DefaultApi.md#delete_hosted_cloud_api_v2_clouds_hosted_cloud_id_delete) | **DELETE** /api/v2/clouds/hosted/{cloud_id} | Delete Hosted Cloud
*DefaultApi* | [**delete_instance_usage_budget_api_v2_instance_usage_budgets_instance_usage_budget_id_delete**](docs/DefaultApi.md#delete_instance_usage_budget_api_v2_instance_usage_budgets_instance_usage_budget_id_delete) | **DELETE** /api/v2/instance_usage_budgets/{instance_usage_budget_id} | Delete Instance Usage Budget
*DefaultApi* | [**delete_machine_api_v2_machines_delete_post**](docs/DefaultApi.md#delete_machine_api_v2_machines_delete_post) | **POST** /api/v2/machines/delete | Delete Machine
*DefaultApi* | [**delete_machine_pool_api_v2_machine_pools_delete_post**](docs/DefaultApi.md#delete_machine_pool_api_v2_machine_pools_delete_post) | **POST** /api/v2/machine_pools/delete | Delete Machine Pool
*DefaultApi* | [**delete_model_api_v2_llm_models_model_id_delete**](docs/DefaultApi.md#delete_model_api_v2_llm_models_model_id_delete) | **DELETE** /api/v2/llm/models/{model_id} | Delete Model
*DefaultApi* | [**delete_project_api_v2_projects_project_id_delete**](docs/DefaultApi.md#delete_project_api_v2_projects_project_id_delete) | **DELETE** /api/v2/projects/{project_id} | Delete Project
*DefaultApi* | [**delete_project_collaborator_api_v2_projects_project_id_collaborators_role_or_identity_id_delete**](docs/DefaultApi.md#delete_project_collaborator_api_v2_projects_project_id_collaborators_role_or_identity_id_delete) | **DELETE** /api/v2/projects/{project_id}/collaborators/{role_or_identity_id} | Delete Project Collaborator
*DefaultApi* | [**delete_resource_notification_api_v2_resource_notifications_resource_notification_id_delete**](docs/DefaultApi.md#delete_resource_notification_api_v2_resource_notifications_resource_notification_id_delete) | **DELETE** /api/v2/resource_notifications/{resource_notification_id} | Delete Resource Notification
*DefaultApi* | [**delete_resource_quota_api_v2_resource_quotas_resource_quota_id_delete**](docs/DefaultApi.md#delete_resource_quota_api_v2_resource_quotas_resource_quota_id_delete) | **DELETE** /api/v2/resource_quotas/{resource_quota_id} | Delete Resource Quota
*DefaultApi* | [**delete_resource_tags_api_v2_tags_resource_delete**](docs/DefaultApi.md#delete_resource_tags_api_v2_tags_resource_delete) | **DELETE** /api/v2/tags/resource | Delete Resource Tags
*DefaultApi* | [**delete_service_api_v2_services_v2_service_id_delete**](docs/DefaultApi.md#delete_service_api_v2_services_v2_service_id_delete) | **DELETE** /api/v2/services-v2/{service_id} | Delete Service
*DefaultApi* | [**delete_template_api_v2_workspace_templates_template_id_delete**](docs/DefaultApi.md#delete_template_api_v2_workspace_templates_template_id_delete) | **DELETE** /api/v2/workspace_templates/{template_id} | Delete Template
*DefaultApi* | [**delete_workspace_api_v2_experimental_workspaces_workspace_id_delete**](docs/DefaultApi.md#delete_workspace_api_v2_experimental_workspaces_workspace_id_delete) | **DELETE** /api/v2/experimental_workspaces/{workspace_id} | Delete Workspace
*DefaultApi* | [**describe_machine_pool_api_v2_machine_pools_describe_post**](docs/DefaultApi.md#describe_machine_pool_api_v2_machine_pools_describe_post) | **POST** /api/v2/machine_pools/describe | Describe Machine Pool
*DefaultApi* | [**describe_machine_pool_machines_api_v2_machine_pools_describe_machines_post**](docs/DefaultApi.md#describe_machine_pool_machines_api_v2_machine_pools_describe_machines_post) | **POST** /api/v2/machine_pools/describe_machines | Describe Machine Pool Machines
*DefaultApi* | [**describe_machine_pool_requests_api_v2_machine_pools_describe_requests_post**](docs/DefaultApi.md#describe_machine_pool_requests_api_v2_machine_pools_describe_requests_post) | **POST** /api/v2/machine_pools/describe_requests | Describe Machine Pool Requests
*DefaultApi* | [**describe_machine_pool_workloads_api_v2_machine_pools_describe_workloads_post**](docs/DefaultApi.md#describe_machine_pool_workloads_api_v2_machine_pools_describe_workloads_post) | **POST** /api/v2/machine_pools/describe_workloads | Describe Machine Pool Workloads
*DefaultApi* | [**describe_system_workload_api_v2_system_workload_cloud_id_describe_post**](docs/DefaultApi.md#describe_system_workload_api_v2_system_workload_cloud_id_describe_post) | **POST** /api/v2/system_workload/{cloud_id}/describe | Describe System Workload
*DefaultApi* | [**detach_machine_pool_from_cloud_api_v2_machine_pools_detach_post**](docs/DefaultApi.md#detach_machine_pool_from_cloud_api_v2_machine_pools_detach_post) | **POST** /api/v2/machine_pools/detach | Detach Machine Pool From Cloud
*DefaultApi* | [**disable_auto_add_users_api_v2_organizations_disable_auto_add_users_put**](docs/DefaultApi.md#disable_auto_add_users_api_v2_organizations_disable_auto_add_users_put) | **PUT** /api/v2/organizations/disable_auto_add_users | Disable Auto Add Users
*DefaultApi* | [**download_aggregated_instance_usage_csv_api_v2_aggregated_instance_usage_download_csv_get**](docs/DefaultApi.md#download_aggregated_instance_usage_csv_api_v2_aggregated_instance_usage_download_csv_get) | **GET** /api/v2/aggregated_instance_usage/download_csv | Download Aggregated Instance Usage Csv
*DefaultApi* | [**download_aggregated_instance_usage_csv_internal_api_v2_aggregated_instance_usage_download_csv_internal_get**](docs/DefaultApi.md#download_aggregated_instance_usage_csv_internal_api_v2_aggregated_instance_usage_download_csv_internal_get) | **GET** /api/v2/aggregated_instance_usage/download_csv_internal | Download Aggregated Instance Usage Csv Internal
*DefaultApi* | [**echo_ip_api_v2_health_echo_ip_get**](docs/DefaultApi.md#echo_ip_api_v2_health_echo_ip_get) | **GET** /api/v2/health/echo_ip | Echo Ip
*DefaultApi* | [**edit_cloud_resource_api_v2_clouds_with_cloud_resource_gcp_router_cloud_id_patch**](docs/DefaultApi.md#edit_cloud_resource_api_v2_clouds_with_cloud_resource_gcp_router_cloud_id_patch) | **PATCH** /api/v2/clouds_with_cloud_resource_gcp_router/{cloud_id} | Edit Cloud Resource
*DefaultApi* | [**edit_cloud_resource_api_v2_clouds_with_cloud_resource_router_cloud_id_patch**](docs/DefaultApi.md#edit_cloud_resource_api_v2_clouds_with_cloud_resource_router_cloud_id_patch) | **PATCH** /api/v2/clouds_with_cloud_resource_router/{cloud_id} | Edit Cloud Resource
*DefaultApi* | [**execute_interactive_command_api_v2_sessions_session_id_execute_interactive_command_post**](docs/DefaultApi.md#execute_interactive_command_api_v2_sessions_session_id_execute_interactive_command_post) | **POST** /api/v2/sessions/{session_id}/execute_interactive_command | Execute Interactive Command
*DefaultApi* | [**fetch_usage_group_by_cloud_api_v2_aggregated_instance_usage_cloud_post**](docs/DefaultApi.md#fetch_usage_group_by_cloud_api_v2_aggregated_instance_usage_cloud_post) | **POST** /api/v2/aggregated_instance_usage/cloud | Fetch Usage Group By Cloud
*DefaultApi* | [**fetch_usage_group_by_cluster_api_v2_aggregated_instance_usage_cluster_post**](docs/DefaultApi.md#fetch_usage_group_by_cluster_api_v2_aggregated_instance_usage_cluster_post) | **POST** /api/v2/aggregated_instance_usage/cluster | Fetch Usage Group By Cluster
*DefaultApi* | [**fetch_usage_group_by_cluster_type_api_v2_aggregated_instance_usage_cluster_type_post**](docs/DefaultApi.md#fetch_usage_group_by_cluster_type_api_v2_aggregated_instance_usage_cluster_type_post) | **POST** /api/v2/aggregated_instance_usage/cluster_type | Fetch Usage Group By Cluster Type
*DefaultApi* | [**fetch_usage_group_by_instance_type_api_v2_aggregated_instance_usage_instance_type_post**](docs/DefaultApi.md#fetch_usage_group_by_instance_type_api_v2_aggregated_instance_usage_instance_type_post) | **POST** /api/v2/aggregated_instance_usage/instance_type | Fetch Usage Group By Instance Type
*DefaultApi* | [**fetch_usage_group_by_project_api_v2_aggregated_instance_usage_project_post**](docs/DefaultApi.md#fetch_usage_group_by_project_api_v2_aggregated_instance_usage_project_post) | **POST** /api/v2/aggregated_instance_usage/project | Fetch Usage Group By Project
*DefaultApi* | [**fetch_usage_group_by_user_api_v2_aggregated_instance_usage_user_post**](docs/DefaultApi.md#fetch_usage_group_by_user_api_v2_aggregated_instance_usage_user_post) | **POST** /api/v2/aggregated_instance_usage/user | Fetch Usage Group By User
*DefaultApi* | [**find_cloud_by_name_api_v2_clouds_find_by_name_post**](docs/DefaultApi.md#find_cloud_by_name_api_v2_clouds_find_by_name_post) | **POST** /api/v2/clouds/find_by_name | Find Cloud By Name
*DefaultApi* | [**find_cloud_resource_by_name_api_v2_clouds_cloud_id_find_cloud_resource_by_name_post**](docs/DefaultApi.md#find_cloud_resource_by_name_api_v2_clouds_cloud_id_find_cloud_resource_by_name_post) | **POST** /api/v2/clouds/{cloud_id}/find_cloud_resource_by_name | Find Cloud Resource By Name
*DefaultApi* | [**find_dataset_api_v2_datasets_find_get**](docs/DefaultApi.md#find_dataset_api_v2_datasets_find_get) | **GET** /api/v2/datasets/find | Find Dataset
*DefaultApi* | [**find_project_by_project_name_api_v2_projects_find_by_name_get**](docs/DefaultApi.md#find_project_by_project_name_api_v2_projects_find_by_name_get) | **GET** /api/v2/projects/find_by_name | Find Project By Project Name
*DefaultApi* | [**finish_session_command_api_v2_session_commands_session_command_id_finish_post**](docs/DefaultApi.md#finish_session_command_api_v2_session_commands_session_command_id_finish_post) | **POST** /api/v2/session_commands/{session_command_id}/finish | Finish Session Command
*DefaultApi* | [**generate_cloud_data_bucket_presigned_upload_url_api_v2_clouds_cloud_id_generate_cloud_data_bucket_presigned_upload_url_post**](docs/DefaultApi.md#generate_cloud_data_bucket_presigned_upload_url_api_v2_clouds_cloud_id_generate_cloud_data_bucket_presigned_upload_url_post) | **POST** /api/v2/clouds/{cloud_id}/generate_cloud_data_bucket_presigned_upload_url | Generate Cloud Data Bucket Presigned Upload Url
*DefaultApi* | [**generate_cloud_data_bucket_presigned_url_api_v2_clouds_cloud_id_generate_cloud_data_bucket_presigned_url_post**](docs/DefaultApi.md#generate_cloud_data_bucket_presigned_url_api_v2_clouds_cloud_id_generate_cloud_data_bucket_presigned_url_post) | **POST** /api/v2/clouds/{cloud_id}/generate_cloud_data_bucket_presigned_url | Generate Cloud Data Bucket Presigned Url
*DefaultApi* | [**get_active_billing_version_api_v2_organization_billing_active_billing_version_get**](docs/DefaultApi.md#get_active_billing_version_api_v2_organization_billing_active_billing_version_get) | **GET** /api/v2/organization_billing/active_billing_version | Get Active Billing Version
*DefaultApi* | [**get_actor_exit_detail_aggregates_api_v2_actors_dashboard_exit_detail_aggregates_get**](docs/DefaultApi.md#get_actor_exit_detail_aggregates_api_v2_actors_dashboard_exit_detail_aggregates_get) | **GET** /api/v2/actors_dashboard/exit_detail_aggregates | Get Actor Exit Detail Aggregates
*DefaultApi* | [**get_actor_job_aggregates_api_v2_actors_dashboard_job_aggregates_get**](docs/DefaultApi.md#get_actor_job_aggregates_api_v2_actors_dashboard_job_aggregates_get) | **GET** /api/v2/actors_dashboard/job_aggregates | Get Actor Job Aggregates
*DefaultApi* | [**get_actor_name_aggregates_api_v2_actors_dashboard_name_aggregates_get**](docs/DefaultApi.md#get_actor_name_aggregates_api_v2_actors_dashboard_name_aggregates_get) | **GET** /api/v2/actors_dashboard/name_aggregates | Get Actor Name Aggregates
*DefaultApi* | [**get_actor_summary_api_v2_actors_dashboard_summary_get**](docs/DefaultApi.md#get_actor_summary_api_v2_actors_dashboard_summary_get) | **GET** /api/v2/actors_dashboard/summary | Get Actor Summary
*DefaultApi* | [**get_actor_table_api_v2_actors_dashboard_table_get**](docs/DefaultApi.md#get_actor_table_api_v2_actors_dashboard_table_get) | **GET** /api/v2/actors_dashboard/table | Get Actor Table
*DefaultApi* | [**get_anyscale_aws_account_api_v2_clouds_anyscale_aws_account_get**](docs/DefaultApi.md#get_anyscale_aws_account_api_v2_clouds_anyscale_aws_account_get) | **GET** /api/v2/clouds/anyscale/aws_account | Get Anyscale Aws Account
*DefaultApi* | [**get_application_template_api_v2_application_templates_application_template_id_get**](docs/DefaultApi.md#get_application_template_api_v2_application_templates_application_template_id_get) | **GET** /api/v2/application_templates/{application_template_id} | Get Application Template
*DefaultApi* | [**get_azure_operator_audience_api_v2_clouds_anyscale_azure_operator_audience_get**](docs/DefaultApi.md#get_azure_operator_audience_api_v2_clouds_anyscale_azure_operator_audience_get) | **GET** /api/v2/clouds/anyscale/azure_operator_audience | Get Azure Operator Audience
*DefaultApi* | [**get_billing_versions_by_organization_api_v2_organization_billing_billing_versions_get**](docs/DefaultApi.md#get_billing_versions_by_organization_api_v2_organization_billing_billing_versions_get) | **GET** /api/v2/organization_billing/billing_versions | Get Billing Versions By Organization
*DefaultApi* | [**get_build_api_v2_builds_build_id_get**](docs/DefaultApi.md#get_build_api_v2_builds_build_id_get) | **GET** /api/v2/builds/{build_id} | Get Build
*DefaultApi* | [**get_build_logs_api_v2_builds_build_id_logs_get**](docs/DefaultApi.md#get_build_logs_api_v2_builds_build_id_logs_get) | **GET** /api/v2/builds/{build_id}/logs | Get Build Logs
*DefaultApi* | [**get_cloud_additional_instance_types_api_v2_clouds_cloud_id_additional_instance_types_get**](docs/DefaultApi.md#get_cloud_additional_instance_types_api_v2_clouds_cloud_id_additional_instance_types_get) | **GET** /api/v2/clouds/{cloud_id}/additional_instance_types | Get Cloud Additional Instance Types
*DefaultApi* | [**get_cloud_api_v2_clouds_cloud_id_get**](docs/DefaultApi.md#get_cloud_api_v2_clouds_cloud_id_get) | **GET** /api/v2/clouds/{cloud_id} | Get Cloud
*DefaultApi* | [**get_cloud_deployment_config_api_v2_clouds_cloud_id_deployment_cloud_deployment_id_config_get**](docs/DefaultApi.md#get_cloud_deployment_config_api_v2_clouds_cloud_id_deployment_cloud_deployment_id_config_get) | **GET** /api/v2/clouds/{cloud_id}/deployment/{cloud_deployment_id}/config | Get Cloud Deployment Config
*DefaultApi* | [**get_cloud_deployments_api_v2_clouds_cloud_id_deployments_get**](docs/DefaultApi.md#get_cloud_deployments_api_v2_clouds_cloud_id_deployments_get) | **GET** /api/v2/clouds/{cloud_id}/deployments | Get Cloud Deployments
*DefaultApi* | [**get_cloud_overview_dashboard_api_v2_clouds_cloud_id_cloud_overview_dashboard_get**](docs/DefaultApi.md#get_cloud_overview_dashboard_api_v2_clouds_cloud_id_cloud_overview_dashboard_get) | **GET** /api/v2/clouds/{cloud_id}/cloud-overview-dashboard | Get Cloud Overview Dashboard
*DefaultApi* | [**get_cloud_project_collaborator_api_v2_projects_project_id_collaborators_clouds_get**](docs/DefaultApi.md#get_cloud_project_collaborator_api_v2_projects_project_id_collaborators_clouds_get) | **GET** /api/v2/projects/{project_id}/collaborators/clouds | Get Cloud Project Collaborator
*DefaultApi* | [**get_cloud_resource_api_v2_clouds_cloud_id_resource_get**](docs/DefaultApi.md#get_cloud_resource_api_v2_clouds_cloud_id_resource_get) | **GET** /api/v2/clouds/{cloud_id}/resource | Get Cloud Resource
*DefaultApi* | [**get_cloud_resources_api_v2_clouds_cloud_id_resources_get**](docs/DefaultApi.md#get_cloud_resources_api_v2_clouds_cloud_id_resources_get) | **GET** /api/v2/clouds/{cloud_id}/resources | Get Cloud Resources
*DefaultApi* | [**get_cloud_with_cloud_resource_api_v2_clouds_with_cloud_resource_gcp_router_cloud_id_get**](docs/DefaultApi.md#get_cloud_with_cloud_resource_api_v2_clouds_with_cloud_resource_gcp_router_cloud_id_get) | **GET** /api/v2/clouds_with_cloud_resource_gcp_router/{cloud_id} | Get Cloud With Cloud Resource
*DefaultApi* | [**get_cloud_with_cloud_resource_api_v2_clouds_with_cloud_resource_router_cloud_id_get**](docs/DefaultApi.md#get_cloud_with_cloud_resource_api_v2_clouds_with_cloud_resource_router_cloud_id_get) | **GET** /api/v2/clouds_with_cloud_resource_router/{cloud_id} | Get Cloud With Cloud Resource
*DefaultApi* | [**get_cluster_access_token_api_v2_authentication_cluster_id_cluster_access_token_get**](docs/DefaultApi.md#get_cluster_access_token_api_v2_authentication_cluster_id_cluster_access_token_get) | **GET** /api/v2/authentication/{cluster_id}/cluster_access_token | Get Cluster Access Token
*DefaultApi* | [**get_cluster_events_api_v2_sessions_session_id_cluster_events_get**](docs/DefaultApi.md#get_cluster_events_api_v2_sessions_session_id_cluster_events_get) | **GET** /api/v2/sessions/{session_id}/cluster_events | Get Cluster Events
*DefaultApi* | [**get_compute_template_api_v2_compute_templates_template_id_get**](docs/DefaultApi.md#get_compute_template_api_v2_compute_templates_template_id_get) | **GET** /api/v2/compute_templates/{template_id} | Get Compute Template
*DefaultApi* | [**get_credits_v2_api_v2_organization_billing_credits_v2_get**](docs/DefaultApi.md#get_credits_v2_api_v2_organization_billing_credits_v2_get) | **GET** /api/v2/organization_billing/credits_v2 | Get Credits V2
*DefaultApi* | [**get_credits_v2_by_organization_api_v2_organization_billing_credits_v2_organization_id_get**](docs/DefaultApi.md#get_credits_v2_by_organization_api_v2_organization_billing_credits_v2_organization_id_get) | **GET** /api/v2/organization_billing/credits_v2/{organization_id} | Get Credits V2 By Organization
*DefaultApi* | [**get_cron_job_api_v2_experimental_cron_jobs_cron_job_id_get**](docs/DefaultApi.md#get_cron_job_api_v2_experimental_cron_jobs_cron_job_id_get) | **GET** /api/v2/experimental_cron_jobs/{cron_job_id} | Get Cron Job
*DefaultApi* | [**get_dags_api_v2_dataset_runs_dags_get**](docs/DefaultApi.md#get_dags_api_v2_dataset_runs_dags_get) | **GET** /api/v2/dataset_runs/dags | Get Dags
*DefaultApi* | [**get_dashboard_metadata_api_v2_dataset_runs_metadata_get**](docs/DefaultApi.md#get_dashboard_metadata_api_v2_dataset_runs_metadata_get) | **GET** /api/v2/dataset_runs/metadata | Get Dashboard Metadata
*DefaultApi* | [**get_dashboard_metrics_api_v2_dataset_runs_metrics_get**](docs/DefaultApi.md#get_dashboard_metrics_api_v2_dataset_runs_metrics_get) | **GET** /api/v2/dataset_runs/metrics | Get Dashboard Metrics
*DefaultApi* | [**get_databricks_connection_api_v2_integrations_connections_databricks_connection_id_get**](docs/DefaultApi.md#get_databricks_connection_api_v2_integrations_connections_databricks_connection_id_get) | **GET** /api/v2/integrations/connections/databricks/{connection_id} | Get Databricks Connection
*DefaultApi* | [**get_dataset_api_v2_datasets_dataset_id_get**](docs/DefaultApi.md#get_dataset_api_v2_datasets_dataset_id_get) | **GET** /api/v2/datasets/{dataset_id} | Get Dataset
*DefaultApi* | [**get_dataset_download_info_api_v2_datasets_download_info_get**](docs/DefaultApi.md#get_dataset_download_info_api_v2_datasets_download_info_get) | **GET** /api/v2/datasets/download_info | Get Dataset Download Info
*DefaultApi* | [**get_dataset_download_url_api_v2_datasets_download_get**](docs/DefaultApi.md#get_dataset_download_url_api_v2_datasets_download_get) | **GET** /api/v2/datasets/download | Get Dataset Download Url
*DefaultApi* | [**get_dataset_logs_download_api_v2_dataset_runs_dataset_logs_get**](docs/DefaultApi.md#get_dataset_logs_download_api_v2_dataset_runs_dataset_logs_get) | **GET** /api/v2/dataset_runs/dataset_logs | Get Dataset Logs Download
*DefaultApi* | [**get_decorated_cluster_api_v2_decorated_sessions_cluster_id_get**](docs/DefaultApi.md#get_decorated_cluster_api_v2_decorated_sessions_cluster_id_get) | **GET** /api/v2/decorated_sessions/{cluster_id} | Get Decorated Cluster
*DefaultApi* | [**get_decorated_interactive_session_api_v2_decorated_interactive_sessions_interactive_session_id_get**](docs/DefaultApi.md#get_decorated_interactive_session_api_v2_decorated_interactive_sessions_interactive_session_id_get) | **GET** /api/v2/decorated_interactive_sessions/{interactive_session_id} | Get Decorated Interactive Session
*DefaultApi* | [**get_decorated_job_api_v2_decorated_jobs_job_id_get**](docs/DefaultApi.md#get_decorated_job_api_v2_decorated_jobs_job_id_get) | **GET** /api/v2/decorated_jobs/{job_id} | Get Decorated Job
*DefaultApi* | [**get_decorated_serve_deployment_api_v2_decorated_serve_deployments_serve_deloyment_id_get**](docs/DefaultApi.md#get_decorated_serve_deployment_api_v2_decorated_serve_deployments_serve_deloyment_id_get) | **GET** /api/v2/decorated_serve_deployments/{serve_deloyment_id} | Get Decorated Serve Deployment
*DefaultApi* | [**get_decorated_support_request_for_user_organization_api_v2_support_requests_get**](docs/DefaultApi.md#get_decorated_support_request_for_user_organization_api_v2_support_requests_get) | **GET** /api/v2/support_requests/ | Get Decorated Support Request For User Organization
*DefaultApi* | [**get_default_cluster_env_build_api_v2_builds_default_py_version_ray_version_get**](docs/DefaultApi.md#get_default_cluster_env_build_api_v2_builds_default_py_version_ray_version_get) | **GET** /api/v2/builds/default/{py_version}/{ray_version} | Get Default Cluster Env Build
*DefaultApi* | [**get_default_compute_config_api_v2_compute_templates_default_cloud_id_get**](docs/DefaultApi.md#get_default_compute_config_api_v2_compute_templates_default_cloud_id_get) | **GET** /api/v2/compute_templates/default/{cloud_id} | Get Default Compute Config
*DefaultApi* | [**get_default_project_api_v2_projects_default_project_get**](docs/DefaultApi.md#get_default_project_api_v2_projects_default_project_get) | **GET** /api/v2/projects/default_project | Get Default Project
*DefaultApi* | [**get_deployment_infra_api_v2_workos_deployment_infra_get**](docs/DefaultApi.md#get_deployment_infra_api_v2_workos_deployment_infra_get) | **GET** /api/v2/workos/deployment_infra | Get Deployment Infra
*DefaultApi* | [**get_directory_sync_readiness_api_v2_organizations_directory_sync_readiness_get**](docs/DefaultApi.md#get_directory_sync_readiness_api_v2_organizations_directory_sync_readiness_get) | **GET** /api/v2/organizations/directory_sync_readiness | Get Directory Sync Readiness
*DefaultApi* | [**get_events_api_v2_sessions_session_id_events_get**](docs/DefaultApi.md#get_events_api_v2_sessions_session_id_events_get) | **GET** /api/v2/sessions/{session_id}/events | Get Events
*DefaultApi* | [**get_instance_usage_budget_api_v2_instance_usage_budgets_instance_usage_budget_id_get**](docs/DefaultApi.md#get_instance_usage_budget_api_v2_instance_usage_budgets_instance_usage_budget_id_get) | **GET** /api/v2/instance_usage_budgets/{instance_usage_budget_id} | Get Instance Usage Budget
*DefaultApi* | [**get_invitation_api_v2_organization_invitations_invitation_id_get**](docs/DefaultApi.md#get_invitation_api_v2_organization_invitations_invitation_id_get) | **GET** /api/v2/organization_invitations/{invitation_id} | Get Invitation
*DefaultApi* | [**get_job_api_v2_decorated_ha_jobs_production_job_id_get**](docs/DefaultApi.md#get_job_api_v2_decorated_ha_jobs_production_job_id_get) | **GET** /api/v2/decorated_ha_jobs/{production_job_id} | Get Job
*DefaultApi* | [**get_job_events_api_v2_decorated_ha_jobs_production_job_id_events_get**](docs/DefaultApi.md#get_job_events_api_v2_decorated_ha_jobs_production_job_id_events_get) | **GET** /api/v2/decorated_ha_jobs/{production_job_id}/events | Get Job Events
*DefaultApi* | [**get_job_logs_download_v2_api_v2_logs_job_logs_download_v2_job_id_get**](docs/DefaultApi.md#get_job_logs_download_v2_api_v2_logs_job_logs_download_v2_job_id_get) | **GET** /api/v2/logs/job_logs_download_v2/{job_id} | Get Job Logs Download V2
*DefaultApi* | [**get_job_queue_api_v2_job_queues_job_queue_id_get**](docs/DefaultApi.md#get_job_queue_api_v2_job_queues_job_queue_id_get) | **GET** /api/v2/job_queues/{job_queue_id} | Get Job Queue
*DefaultApi* | [**get_jobs_api_v2_dataset_runs_jobs_get**](docs/DefaultApi.md#get_jobs_api_v2_dataset_runs_jobs_get) | **GET** /api/v2/dataset_runs/jobs | Get Jobs
*DefaultApi* | [**get_latest_cloud_resource_api_v2_sessions_cluster_id_latest_cloud_resource_get**](docs/DefaultApi.md#get_latest_cloud_resource_api_v2_sessions_cluster_id_latest_cloud_resource_get) | **GET** /api/v2/sessions/{cluster_id}/latest_cloud_resource | Get Latest Cloud Resource
*DefaultApi* | [**get_lb_resource_api_v2_clouds_cloud_id_get_lb_resource_post**](docs/DefaultApi.md#get_lb_resource_api_v2_clouds_cloud_id_get_lb_resource_post) | **POST** /api/v2/clouds/{cloud_id}/get_lb_resource | Get Lb Resource
*DefaultApi* | [**get_lb_resource_api_v2_clouds_with_cloud_resource_gcp_router_cloud_id_get_lb_resource_post**](docs/DefaultApi.md#get_lb_resource_api_v2_clouds_with_cloud_resource_gcp_router_cloud_id_get_lb_resource_post) | **POST** /api/v2/clouds_with_cloud_resource_gcp_router/{cloud_id}/get_lb_resource | Get Lb Resource
*DefaultApi* | [**get_lb_resource_api_v2_clouds_with_cloud_resource_router_cloud_id_get_lb_resource_post**](docs/DefaultApi.md#get_lb_resource_api_v2_clouds_with_cloud_resource_router_cloud_id_get_lb_resource_post) | **POST** /api/v2/clouds_with_cloud_resource_router/{cloud_id}/get_lb_resource | Get Lb Resource
*DefaultApi* | [**get_lineage_api_v2_lineage_get**](docs/DefaultApi.md#get_lineage_api_v2_lineage_get) | **GET** /api/v2/lineage/ | Get Lineage
*DefaultApi* | [**get_lineage_artifact_api_v2_lineage_artifacts_artifact_id_get**](docs/DefaultApi.md#get_lineage_artifact_api_v2_lineage_artifacts_artifact_id_get) | **GET** /api/v2/lineage/artifacts/{artifact_id} | Get Lineage Artifact
*DefaultApi* | [**get_lineage_workload_api_v2_lineage_workloads_workload_id_get**](docs/DefaultApi.md#get_lineage_workload_api_v2_lineage_workloads_workload_id_get) | **GET** /api/v2/lineage/workloads/{workload_id} | Get Lineage Workload
*DefaultApi* | [**get_log_files_api_v2_logs_get_log_files_post**](docs/DefaultApi.md#get_log_files_api_v2_logs_get_log_files_post) | **POST** /api/v2/logs/get_log_files | Get Log Files
*DefaultApi* | [**get_manage_billing_url_api_v2_organization_billing_manage_billing_url_get**](docs/DefaultApi.md#get_manage_billing_url_api_v2_organization_billing_manage_billing_url_get) | **GET** /api/v2/organization_billing/manage_billing_url | Get Manage Billing Url
*DefaultApi* | [**get_metric_names_api_v2_metrics_names_get**](docs/DefaultApi.md#get_metric_names_api_v2_metrics_names_get) | **GET** /api/v2/metrics/names | Get Metric Names
*DefaultApi* | [**get_metrics_for_nodes_api_v2_cluster_dashboard_metrics_get**](docs/DefaultApi.md#get_metrics_for_nodes_api_v2_cluster_dashboard_metrics_get) | **GET** /api/v2/cluster_dashboard/metrics | Get Metrics For Nodes
*DefaultApi* | [**get_metronome_customer_info_api_v2_metronome_customer_info_organization_id_get**](docs/DefaultApi.md#get_metronome_customer_info_api_v2_metronome_customer_info_organization_id_get) | **GET** /api/v2/metronome_customer_info/{organization_id} | Get Metronome Customer Info
*DefaultApi* | [**get_metronome_embedded_usage_dashboard_api_v2_organization_billing_metronome_embedded_dashboard_url_dashboard_type_get**](docs/DefaultApi.md#get_metronome_embedded_usage_dashboard_api_v2_organization_billing_metronome_embedded_dashboard_url_dashboard_type_get) | **GET** /api/v2/organization_billing/metronome_embedded_dashboard_url/{dashboard_type} | Get Metronome Embedded Usage Dashboard
*DefaultApi* | [**get_metronome_embedded_usage_dashboard_by_organization_api_v2_organization_billing_organization_id_metronome_embedded_dashboard_url_dashboard_type_get**](docs/DefaultApi.md#get_metronome_embedded_usage_dashboard_by_organization_api_v2_organization_billing_organization_id_metronome_embedded_dashboard_url_dashboard_type_get) | **GET** /api/v2/organization_billing/{organization_id}/metronome_embedded_dashboard_url/{dashboard_type} | Get Metronome Embedded Usage Dashboard By Organization
*DefaultApi* | [**get_model_api_v2_llm_models_model_id_get**](docs/DefaultApi.md#get_model_api_v2_llm_models_model_id_get) | **GET** /api/v2/llm/models/{model_id} | Get Model
*DefaultApi* | [**get_model_by_job_id_api_v2_llm_models_get_by_job_id_job_id_get**](docs/DefaultApi.md#get_model_by_job_id_api_v2_llm_models_get_by_job_id_job_id_get) | **GET** /api/v2/llm/models/get_by_job_id/{job_id} | Get Model By Job Id
*DefaultApi* | [**get_node_api_v2_cluster_dashboard_node_id_get**](docs/DefaultApi.md#get_node_api_v2_cluster_dashboard_node_id_get) | **GET** /api/v2/cluster_dashboard/{node_id} | Get Node
*DefaultApi* | [**get_nodes_api_v2_cluster_dashboard_get**](docs/DefaultApi.md#get_nodes_api_v2_cluster_dashboard_get) | **GET** /api/v2/cluster_dashboard/ | Get Nodes
*DefaultApi* | [**get_oauth_login_url_api_v2_integrations_oauth_login_get**](docs/DefaultApi.md#get_oauth_login_url_api_v2_integrations_oauth_login_get) | **GET** /api/v2/integrations/oauth/login | Get Oauth Login Url
*DefaultApi* | [**get_operator_events_api_v2_dataset_runs_operator_events_get**](docs/DefaultApi.md#get_operator_events_api_v2_dataset_runs_operator_events_get) | **GET** /api/v2/dataset_runs/operator_events | Get Operator Events
*DefaultApi* | [**get_operator_metrics_api_v2_dataset_runs_operator_get**](docs/DefaultApi.md#get_operator_metrics_api_v2_dataset_runs_operator_get) | **GET** /api/v2/dataset_runs/operator | Get Operator Metrics
*DefaultApi* | [**get_or_create_build_from_image_uri_api_v2_builds_get_or_create_build_from_image_uri_post**](docs/DefaultApi.md#get_or_create_build_from_image_uri_api_v2_builds_get_or_create_build_from_image_uri_post) | **POST** /api/v2/builds/get_or_create_build_from_image_uri | Get Or Create Build From Image Uri
*DefaultApi* | [**get_organization_metronome_usage_alerts_api_v2_organization_billing_alerts_get**](docs/DefaultApi.md#get_organization_metronome_usage_alerts_api_v2_organization_billing_alerts_get) | **GET** /api/v2/organization_billing/alerts | Get Organization Metronome Usage Alerts
*DefaultApi* | [**get_plan_status_api_v2_organization_billing_plan_status_get**](docs/DefaultApi.md#get_plan_status_api_v2_organization_billing_plan_status_get) | **GET** /api/v2/organization_billing/plan_status | Get Plan Status
*DefaultApi* | [**get_project_api_v2_projects_project_id_get**](docs/DefaultApi.md#get_project_api_v2_projects_project_id_get) | **GET** /api/v2/projects/{project_id} | Get Project
*DefaultApi* | [**get_project_default_session_name_api_v2_projects_project_id_default_session_name_get**](docs/DefaultApi.md#get_project_default_session_name_api_v2_projects_project_id_default_session_name_get) | **GET** /api/v2/projects/{project_id}/default_session_name | Get Project Default Session Name
*DefaultApi* | [**get_recent_cluster_compute_configs_api_v2_recent_activity_cluster_compute_configs_get**](docs/DefaultApi.md#get_recent_cluster_compute_configs_api_v2_recent_activity_cluster_compute_configs_get) | **GET** /api/v2/recent_activity/cluster_compute_configs | Get Recent Cluster Compute Configs
*DefaultApi* | [**get_recent_cluster_environments_api_v2_recent_activity_cluster_environment_builds_get**](docs/DefaultApi.md#get_recent_cluster_environments_api_v2_recent_activity_cluster_environment_builds_get) | **GET** /api/v2/recent_activity/cluster_environment_builds | Get Recent Cluster Environments
*DefaultApi* | [**get_regions_and_zones_api_v2_aws_info_regions_and_zones_get**](docs/DefaultApi.md#get_regions_and_zones_api_v2_aws_info_regions_and_zones_get) | **GET** /api/v2/aws_info/regions_and_zones | Get Regions And Zones
*DefaultApi* | [**get_regions_and_zones_api_v2_clouds_gcp_regions_and_zones_get**](docs/DefaultApi.md#get_regions_and_zones_api_v2_clouds_gcp_regions_and_zones_get) | **GET** /api/v2/clouds/gcp/regions_and_zones | Get Regions And Zones
*DefaultApi* | [**get_resource_notification_api_v2_resource_notifications_resource_notification_id_get**](docs/DefaultApi.md#get_resource_notification_api_v2_resource_notifications_resource_notification_id_get) | **GET** /api/v2/resource_notifications/{resource_notification_id} | Get Resource Notification
*DefaultApi* | [**get_resource_policy_api_v2_policy_resource_type_resource_id_get**](docs/DefaultApi.md#get_resource_policy_api_v2_policy_resource_type_resource_id_get) | **GET** /api/v2/policy/{resource_type}/{resource_id} | Get Resource Policy
*DefaultApi* | [**get_resource_quota_api_v2_resource_quotas_resource_quota_id_get**](docs/DefaultApi.md#get_resource_quota_api_v2_resource_quotas_resource_quota_id_get) | **GET** /api/v2/resource_quotas/{resource_quota_id} | Get Resource Quota
*DefaultApi* | [**get_root_cause_for_job_api_v2_iknow_get**](docs/DefaultApi.md#get_root_cause_for_job_api_v2_iknow_get) | **GET** /api/v2/iknow/ | Get Root Cause For Job
*DefaultApi* | [**get_sensitive_message_presigned_url_api_v2_decorated_ha_jobs_production_job_id_events_ha_job_event_id_sensitive_message_presigned_url_get**](docs/DefaultApi.md#get_sensitive_message_presigned_url_api_v2_decorated_ha_jobs_production_job_id_events_ha_job_event_id_sensitive_message_presigned_url_get) | **GET** /api/v2/decorated_ha_jobs/{production_job_id}/events/{ha_job_event_id}/sensitive_message_presigned_url | Get Sensitive Message Presigned Url
*DefaultApi* | [**get_serve_logs_download_api_v2_logs_serve_logs_download_cluster_id_get**](docs/DefaultApi.md#get_serve_logs_download_api_v2_logs_serve_logs_download_cluster_id_get) | **GET** /api/v2/logs/serve_logs_download/{cluster_id} | Get Serve Logs Download
*DefaultApi* | [**get_service_api_v2_services_v2_service_id_get**](docs/DefaultApi.md#get_service_api_v2_services_v2_service_id_get) | **GET** /api/v2/services-v2/{service_id} | Get Service
*DefaultApi* | [**get_service_event_verbose_message_api_v2_services_v2_events_event_id_verbose_message_get**](docs/DefaultApi.md#get_service_event_verbose_message_api_v2_services_v2_events_event_id_verbose_message_get) | **GET** /api/v2/services-v2/events/{event_id}/verbose_message | Get Service Event Verbose Message
*DefaultApi* | [**get_service_events_api_v2_services_v2_service_id_events_get**](docs/DefaultApi.md#get_service_events_api_v2_services_v2_service_id_events_get) | **GET** /api/v2/services-v2/{service_id}/events | Get Service Events
*DefaultApi* | [**get_service_version_api_v2_services_v2_service_id_versions_service_version_name_get**](docs/DefaultApi.md#get_service_version_api_v2_services_v2_service_id_versions_service_version_name_get) | **GET** /api/v2/services-v2/{service_id}/versions/{service_version_name} | Get Service Version
*DefaultApi* | [**get_service_versions_api_v2_services_v2_service_id_versions_get**](docs/DefaultApi.md#get_service_versions_api_v2_services_v2_service_id_versions_get) | **GET** /api/v2/services-v2/{service_id}/versions | Get Service Versions
*DefaultApi* | [**get_session_api_v2_sessions_session_id_get**](docs/DefaultApi.md#get_session_api_v2_sessions_session_id_get) | **GET** /api/v2/sessions/{session_id} | Get Session
*DefaultApi* | [**get_session_command_logs_download_api_v2_logs_session_command_logs_session_id_session_command_id_get**](docs/DefaultApi.md#get_session_command_logs_download_api_v2_logs_session_command_logs_session_id_session_command_id_get) | **GET** /api/v2/logs/session_command_logs/{session_id}/{session_command_id} | Get Session Command Logs Download
*DefaultApi* | [**get_session_commands_history_api_v2_session_commands_get**](docs/DefaultApi.md#get_session_commands_history_api_v2_session_commands_get) | **GET** /api/v2/session_commands/ | Get Session Commands History
*DefaultApi* | [**get_session_head_ip_api_v2_sessions_session_id_head_ip_get**](docs/DefaultApi.md#get_session_head_ip_api_v2_sessions_session_id_head_ip_get) | **GET** /api/v2/sessions/{session_id}/head_ip | Get Session Head Ip
*DefaultApi* | [**get_session_ssh_key_api_v2_sessions_session_id_ssh_key_get**](docs/DefaultApi.md#get_session_ssh_key_api_v2_sessions_session_id_ssh_key_get) | **GET** /api/v2/sessions/{session_id}/ssh_key | Get Session Ssh Key
*DefaultApi* | [**get_startup_logs_api_v2_sessions_session_id_startup_logs_get**](docs/DefaultApi.md#get_startup_logs_api_v2_sessions_session_id_startup_logs_get) | **GET** /api/v2/sessions/{session_id}/startup_logs | Get Startup Logs
*DefaultApi* | [**get_table_metadata_api_v2_data_catalogs_connections_connection_id_catalogs_catalog_id_schemas_schema_id_tables_table_id_metadata_get**](docs/DefaultApi.md#get_table_metadata_api_v2_data_catalogs_connections_connection_id_catalogs_catalog_id_schemas_schema_id_tables_table_id_metadata_get) | **GET** /api/v2/data_catalogs/connections/{connection_id}/catalogs/{catalog_id}/schemas/{schema_id}/tables/{table_id}/metadata | Get Table Metadata
*DefaultApi* | [**get_table_preview_api_v2_data_catalogs_connections_connection_id_catalogs_catalog_id_schemas_schema_id_tables_table_id_preview_get**](docs/DefaultApi.md#get_table_preview_api_v2_data_catalogs_connections_connection_id_catalogs_catalog_id_schemas_schema_id_tables_table_id_preview_get) | **GET** /api/v2/data_catalogs/connections/{connection_id}/catalogs/{catalog_id}/schemas/{schema_id}/tables/{table_id}/preview | Get Table Preview
*DefaultApi* | [**get_tags_for_resource_api_v2_tags_resource_get**](docs/DefaultApi.md#get_tags_for_resource_api_v2_tags_resource_get) | **GET** /api/v2/tags/resource | Get Tags For Resource
*DefaultApi* | [**get_task_exception_aggregates_api_v2_tasks_dashboard_aggregate_by_exception_get**](docs/DefaultApi.md#get_task_exception_aggregates_api_v2_tasks_dashboard_aggregate_by_exception_get) | **GET** /api/v2/tasks_dashboard/aggregate_by_exception | Get Task Exception Aggregates
*DefaultApi* | [**get_task_function_aggregates_api_v2_tasks_dashboard_aggregate_by_function_get**](docs/DefaultApi.md#get_task_function_aggregates_api_v2_tasks_dashboard_aggregate_by_function_get) | **GET** /api/v2/tasks_dashboard/aggregate_by_function | Get Task Function Aggregates
*DefaultApi* | [**get_task_job_aggregates_api_v2_tasks_dashboard_aggregate_by_job_get**](docs/DefaultApi.md#get_task_job_aggregates_api_v2_tasks_dashboard_aggregate_by_job_get) | **GET** /api/v2/tasks_dashboard/aggregate_by_job | Get Task Job Aggregates
*DefaultApi* | [**get_task_summary_api_v2_tasks_dashboard_summary_get**](docs/DefaultApi.md#get_task_summary_api_v2_tasks_dashboard_summary_get) | **GET** /api/v2/tasks_dashboard/summary | Get Task Summary
*DefaultApi* | [**get_task_table_api_v2_tasks_dashboard_table_get**](docs/DefaultApi.md#get_task_table_api_v2_tasks_dashboard_table_get) | **GET** /api/v2/tasks_dashboard/table | Get Task Table
*DefaultApi* | [**get_template_api_v2_workspace_templates_template_id_get**](docs/DefaultApi.md#get_template_api_v2_workspace_templates_template_id_get) | **GET** /api/v2/workspace_templates/{template_id} | Get Template
*DefaultApi* | [**get_template_readme_api_v2_experimental_workspaces_template_readme_template_id_get**](docs/DefaultApi.md#get_template_readme_api_v2_experimental_workspaces_template_readme_template_id_get) | **GET** /api/v2/experimental_workspaces/template/readme/{template_id} | Get Template Readme
*DefaultApi* | [**get_total_usage_api_v2_aggregated_instance_usage_get**](docs/DefaultApi.md#get_total_usage_api_v2_aggregated_instance_usage_get) | **GET** /api/v2/aggregated_instance_usage/ | Get Total Usage
*DefaultApi* | [**get_train_logs_download_api_v2_train_runs_logs_get**](docs/DefaultApi.md#get_train_logs_download_api_v2_train_runs_logs_get) | **GET** /api/v2/train_runs/logs | Get Train Logs Download
*DefaultApi* | [**get_train_runs_api_v2_train_runs_get**](docs/DefaultApi.md#get_train_runs_api_v2_train_runs_get) | **GET** /api/v2/train_runs/ | Get Train Runs
*DefaultApi* | [**get_unified_events_api_v2_events_entity_type_entity_id_events_get**](docs/DefaultApi.md#get_unified_events_api_v2_events_entity_type_entity_id_events_get) | **GET** /api/v2/events/{entity_type}/{entity_id}/events | Get Unified Events
*DefaultApi* | [**get_user_group_api_v2_user_groups_group_id_get**](docs/DefaultApi.md#get_user_group_api_v2_user_groups_group_id_get) | **GET** /api/v2/user_groups/{group_id} | Get User Group
*DefaultApi* | [**get_user_info_api_v2_userinfo_get**](docs/DefaultApi.md#get_user_info_api_v2_userinfo_get) | **GET** /api/v2/userinfo/ | Get User Info
*DefaultApi* | [**get_version_api_v2_workspace_templates_template_id_versions_version_id_get**](docs/DefaultApi.md#get_version_api_v2_workspace_templates_template_id_versions_version_id_get) | **GET** /api/v2/workspace_templates/{template_id}/versions/{version_id} | Get Version
*DefaultApi* | [**get_workos_authorize_url_api_v2_workos_authorize_get**](docs/DefaultApi.md#get_workos_authorize_url_api_v2_workos_authorize_get) | **GET** /api/v2/workos/authorize | Get Workos Authorize Url
*DefaultApi* | [**get_workspace_api_v2_experimental_workspaces_workspace_id_get**](docs/DefaultApi.md#get_workspace_api_v2_experimental_workspaces_workspace_id_get) | **GET** /api/v2/experimental_workspaces/{workspace_id} | Get Workspace
*DefaultApi* | [**get_workspace_dataplane_artifacts_api_v2_experimental_workspaces_workspace_id_dataplane_artifacts_get**](docs/DefaultApi.md#get_workspace_dataplane_artifacts_api_v2_experimental_workspaces_workspace_id_dataplane_artifacts_get) | **GET** /api/v2/experimental_workspaces/{workspace_id}/dataplane_artifacts | Get Workspace Dataplane Artifacts
*DefaultApi* | [**get_workspace_events_api_v2_experimental_workspaces_workspace_id_events_get**](docs/DefaultApi.md#get_workspace_events_api_v2_experimental_workspaces_workspace_id_events_get) | **GET** /api/v2/experimental_workspaces/{workspace_id}/events | Get Workspace Events
*DefaultApi* | [**get_workspace_proxied_dataplane_artifacts_api_v2_experimental_workspaces_workspace_id_proxied_dataplane_artifacts_get**](docs/DefaultApi.md#get_workspace_proxied_dataplane_artifacts_api_v2_experimental_workspaces_workspace_id_proxied_dataplane_artifacts_get) | **GET** /api/v2/experimental_workspaces/{workspace_id}/proxied_dataplane_artifacts | Get Workspace Proxied Dataplane Artifacts
*DefaultApi* | [**get_workspace_readme_api_v2_experimental_workspaces_workspace_id_readme_get**](docs/DefaultApi.md#get_workspace_readme_api_v2_experimental_workspaces_workspace_id_readme_get) | **GET** /api/v2/experimental_workspaces/{workspace_id}/readme | Get Workspace Readme
*DefaultApi* | [**get_workspace_template_cluster_environment_api_v2_experimental_workspaces_template_template_id_cluster_environment_get**](docs/DefaultApi.md#get_workspace_template_cluster_environment_api_v2_experimental_workspaces_template_template_id_cluster_environment_get) | **GET** /api/v2/experimental_workspaces/template/{template_id}/cluster_environment | Get Workspace Template Cluster Environment
*DefaultApi* | [**get_workspace_template_compute_config_api_v2_experimental_workspaces_template_template_id_compute_config_get**](docs/DefaultApi.md#get_workspace_template_compute_config_api_v2_experimental_workspaces_template_template_id_compute_config_get) | **GET** /api/v2/experimental_workspaces/template/{template_id}/compute_config | Get Workspace Template Compute Config
*DefaultApi* | [**handle_cloud_metrics_auth_api_v2_authentication_cloud_id_cloud_persistent_metrics_get**](docs/DefaultApi.md#handle_cloud_metrics_auth_api_v2_authentication_cloud_id_cloud_persistent_metrics_get) | **GET** /api/v2/authentication/{cloud_id}/cloud_persistent_metrics | Handle Cloud Metrics Auth
*DefaultApi* | [**handle_cluster_auth_api_v2_authentication_cluster_id_cluster_get**](docs/DefaultApi.md#handle_cluster_auth_api_v2_authentication_cluster_id_cluster_get) | **GET** /api/v2/authentication/{cluster_id}/cluster | Handle Cluster Auth
*DefaultApi* | [**handle_webhook_api_v2_metronome_webhooks_handle_webhook_post**](docs/DefaultApi.md#handle_webhook_api_v2_metronome_webhooks_handle_webhook_post) | **POST** /api/v2/metronome_webhooks/handle_webhook | Handle Webhook
*DefaultApi* | [**health_check_api_v2_health_get**](docs/DefaultApi.md#health_check_api_v2_health_get) | **GET** /api/v2/health/ | Health Check
*DefaultApi* | [**import_cluster_environment_api_v2_application_templates_import_post**](docs/DefaultApi.md#import_cluster_environment_api_v2_application_templates_import_post) | **POST** /api/v2/application_templates/import | Import Cluster Environment
*DefaultApi* | [**invalidate_invitation_api_v2_organization_invitations_invitation_id_invalidate_post**](docs/DefaultApi.md#invalidate_invitation_api_v2_organization_invitations_invitation_id_invalidate_post) | **POST** /api/v2/organization_invitations/{invitation_id}/invalidate | Invalidate Invitation
*DefaultApi* | [**is_valid_api_v2_authentication_hex_token_id_is_valid_post**](docs/DefaultApi.md#is_valid_api_v2_authentication_hex_token_id_is_valid_post) | **POST** /api/v2/authentication/{hex_token_id}/is_valid | Is Valid
*DefaultApi* | [**list_api_keys_api_v2_users_api_keys_get**](docs/DefaultApi.md#list_api_keys_api_v2_users_api_keys_get) | **GET** /api/v2/users/api_keys | List Api Keys
*DefaultApi* | [**list_api_keys_for_admin_api_v2_users_admin_api_keys_get**](docs/DefaultApi.md#list_api_keys_for_admin_api_v2_users_admin_api_keys_get) | **GET** /api/v2/users/admin/api_keys | List Api Keys For Admin
*DefaultApi* | [**list_application_templates_api_v2_application_templates_get**](docs/DefaultApi.md#list_application_templates_api_v2_application_templates_get) | **GET** /api/v2/application_templates/ | List Application Templates
*DefaultApi* | [**list_builds_api_v2_builds_get**](docs/DefaultApi.md#list_builds_api_v2_builds_get) | **GET** /api/v2/builds/ | List Builds
*DefaultApi* | [**list_catalogs_in_connection_api_v2_data_catalogs_connections_connection_id_catalogs_get**](docs/DefaultApi.md#list_catalogs_in_connection_api_v2_data_catalogs_connections_connection_id_catalogs_get) | **GET** /api/v2/data_catalogs/connections/{connection_id}/catalogs | List Catalogs In Connection
*DefaultApi* | [**list_clouds_api_v2_clouds_get**](docs/DefaultApi.md#list_clouds_api_v2_clouds_get) | **GET** /api/v2/clouds/ | List Clouds
*DefaultApi* | [**list_configurations_api_v2_organization_configurations_get**](docs/DefaultApi.md#list_configurations_api_v2_organization_configurations_get) | **GET** /api/v2/organization_configurations/ | List Configurations
*DefaultApi* | [**list_cron_jobs_api_v2_experimental_cron_jobs_get**](docs/DefaultApi.md#list_cron_jobs_api_v2_experimental_cron_jobs_get) | **GET** /api/v2/experimental_cron_jobs/ | List Cron Jobs
*DefaultApi* | [**list_data_catalog_connections_api_v2_data_catalogs_connections_get**](docs/DefaultApi.md#list_data_catalog_connections_api_v2_data_catalogs_connections_get) | **GET** /api/v2/data_catalogs/connections | List Data Catalog Connections
*DefaultApi* | [**list_databricks_connections_api_v2_integrations_connections_databricks_get**](docs/DefaultApi.md#list_databricks_connections_api_v2_integrations_connections_databricks_get) | **GET** /api/v2/integrations/connections/databricks | List Databricks Connections
*DefaultApi* | [**list_dataset_versions_api_v2_datasets_versions_get**](docs/DefaultApi.md#list_dataset_versions_api_v2_datasets_versions_get) | **GET** /api/v2/datasets/versions | List Dataset Versions
*DefaultApi* | [**list_datasets_api_v2_datasets_get**](docs/DefaultApi.md#list_datasets_api_v2_datasets_get) | **GET** /api/v2/datasets/ | List Datasets
*DefaultApi* | [**list_decorated_clusters_api_v2_decorated_sessions_get**](docs/DefaultApi.md#list_decorated_clusters_api_v2_decorated_sessions_get) | **GET** /api/v2/decorated_sessions/ | List Decorated Clusters
*DefaultApi* | [**list_decorated_interactive_sessions_api_v2_decorated_interactive_sessions_get**](docs/DefaultApi.md#list_decorated_interactive_sessions_api_v2_decorated_interactive_sessions_get) | **GET** /api/v2/decorated_interactive_sessions/ | List Decorated Interactive Sessions
*DefaultApi* | [**list_decorated_jobs_api_v2_decorated_ha_jobs_get**](docs/DefaultApi.md#list_decorated_jobs_api_v2_decorated_ha_jobs_get) | **GET** /api/v2/decorated_ha_jobs/ | List Decorated Jobs
*DefaultApi* | [**list_decorated_serve_deployments_api_v2_decorated_serve_deployments_get**](docs/DefaultApi.md#list_decorated_serve_deployments_api_v2_decorated_serve_deployments_get) | **GET** /api/v2/decorated_serve_deployments/ | List Decorated Serve Deployments
*DefaultApi* | [**list_instance_usage_budgets_api_v2_instance_usage_budgets_get**](docs/DefaultApi.md#list_instance_usage_budgets_api_v2_instance_usage_budgets_get) | **GET** /api/v2/instance_usage_budgets/ | List Instance Usage Budgets
*DefaultApi* | [**list_invitations_api_v2_organization_invitations_get**](docs/DefaultApi.md#list_invitations_api_v2_organization_invitations_get) | **GET** /api/v2/organization_invitations/ | List Invitations
*DefaultApi* | [**list_job_queues_api_v2_job_queues_post**](docs/DefaultApi.md#list_job_queues_api_v2_job_queues_post) | **POST** /api/v2/job_queues/ | List Job Queues
*DefaultApi* | [**list_job_reports_api_v2_job_reports_get**](docs/DefaultApi.md#list_job_reports_api_v2_job_reports_get) | **GET** /api/v2/job_reports/ | List Job Reports
*DefaultApi* | [**list_job_states_api_v2_decorated_ha_job_states_get**](docs/DefaultApi.md#list_job_states_api_v2_decorated_ha_job_states_get) | **GET** /api/v2/decorated_ha_job_states/ | List Job States
*DefaultApi* | [**list_jobs_api_v2_decorated_unified_jobs_get**](docs/DefaultApi.md#list_jobs_api_v2_decorated_unified_jobs_get) | **GET** /api/v2/decorated_unified_jobs/ | List Jobs
*DefaultApi* | [**list_keys_api_v2_tags_keys_get**](docs/DefaultApi.md#list_keys_api_v2_tags_keys_get) | **GET** /api/v2/tags/keys | List Keys
*DefaultApi* | [**list_lineage_artifacts_api_v2_lineage_artifacts_get**](docs/DefaultApi.md#list_lineage_artifacts_api_v2_lineage_artifacts_get) | **GET** /api/v2/lineage/artifacts | List Lineage Artifacts
*DefaultApi* | [**list_lineage_workloads_api_v2_lineage_workloads_get**](docs/DefaultApi.md#list_lineage_workloads_api_v2_lineage_workloads_get) | **GET** /api/v2/lineage/workloads | List Lineage Workloads
*DefaultApi* | [**list_long_running_workloads_api_v2_decorated_sessions_long_running_workloads_get**](docs/DefaultApi.md#list_long_running_workloads_api_v2_decorated_sessions_long_running_workloads_get) | **GET** /api/v2/decorated_sessions/long-running-workloads | List Long Running Workloads
*DefaultApi* | [**list_machine_pools_api_v2_machine_pools_get**](docs/DefaultApi.md#list_machine_pools_api_v2_machine_pools_get) | **GET** /api/v2/machine_pools/ | List Machine Pools
*DefaultApi* | [**list_machines_api_v2_machines_get**](docs/DefaultApi.md#list_machines_api_v2_machines_get) | **GET** /api/v2/machines/ | List Machines
*DefaultApi* | [**list_metronome_customer_info_api_v2_metronome_customer_info_get**](docs/DefaultApi.md#list_metronome_customer_info_api_v2_metronome_customer_info_get) | **GET** /api/v2/metronome_customer_info/ | List Metronome Customer Info
*DefaultApi* | [**list_models_api_v2_llm_models_get**](docs/DefaultApi.md#list_models_api_v2_llm_models_get) | **GET** /api/v2/llm/models | List Models
*DefaultApi* | [**list_organization_collaborators_api_v2_organization_collaborators_get**](docs/DefaultApi.md#list_organization_collaborators_api_v2_organization_collaborators_get) | **GET** /api/v2/organization_collaborators/ | List Organization Collaborators
*DefaultApi* | [**list_project_collaborators_api_v2_projects_project_id_collaborators_users_get**](docs/DefaultApi.md#list_project_collaborators_api_v2_projects_project_id_collaborators_users_get) | **GET** /api/v2/projects/{project_id}/collaborators/users | List Project Collaborators
*DefaultApi* | [**list_projects_api_v2_projects_get**](docs/DefaultApi.md#list_projects_api_v2_projects_get) | **GET** /api/v2/projects/ | List Projects
*DefaultApi* | [**list_ray_sessions_api_v2_tasks_dashboard_list_ray_sessions_get**](docs/DefaultApi.md#list_ray_sessions_api_v2_tasks_dashboard_list_ray_sessions_get) | **GET** /api/v2/tasks_dashboard/list_ray_sessions | List Ray Sessions
*DefaultApi* | [**list_recommended_workspace_templates_api_v2_experimental_workspaces_templates_recommended_get**](docs/DefaultApi.md#list_recommended_workspace_templates_api_v2_experimental_workspaces_templates_recommended_get) | **GET** /api/v2/experimental_workspaces/templates/recommended | List Recommended Workspace Templates
*DefaultApi* | [**list_resource_policies_api_v2_policy_resource_type_get**](docs/DefaultApi.md#list_resource_policies_api_v2_policy_resource_type_get) | **GET** /api/v2/policy/{resource_type} | List Resource Policies
*DefaultApi* | [**list_schemas_in_catalog_api_v2_data_catalogs_connections_connection_id_catalogs_catalog_id_schemas_get**](docs/DefaultApi.md#list_schemas_in_catalog_api_v2_data_catalogs_connections_connection_id_catalogs_catalog_id_schemas_get) | **GET** /api/v2/data_catalogs/connections/{connection_id}/catalogs/{catalog_id}/schemas | List Schemas In Catalog
*DefaultApi* | [**list_scim_user_permissions_api_v2_scim_list_user_permissions_get**](docs/DefaultApi.md#list_scim_user_permissions_api_v2_scim_list_user_permissions_get) | **GET** /api/v2/scim/list-user-permissions | List Scim User Permissions
*DefaultApi* | [**list_services_api_v2_services_v2_get**](docs/DefaultApi.md#list_services_api_v2_services_v2_get) | **GET** /api/v2/services-v2/ | List Services
*DefaultApi* | [**list_sessions_api_v2_sessions_get**](docs/DefaultApi.md#list_sessions_api_v2_sessions_get) | **GET** /api/v2/sessions/ | List Sessions
*DefaultApi* | [**list_tables_in_schema_api_v2_data_catalogs_connections_connection_id_catalogs_catalog_id_schemas_schema_id_tables_get**](docs/DefaultApi.md#list_tables_in_schema_api_v2_data_catalogs_connections_connection_id_catalogs_catalog_id_schemas_schema_id_tables_get) | **GET** /api/v2/data_catalogs/connections/{connection_id}/catalogs/{catalog_id}/schemas/{schema_id}/tables | List Tables In Schema
*DefaultApi* | [**list_template_versions_api_v2_workspace_templates_template_id_versions_get**](docs/DefaultApi.md#list_template_versions_api_v2_workspace_templates_template_id_versions_get) | **GET** /api/v2/workspace_templates/{template_id}/versions | List Template Versions
*DefaultApi* | [**list_templates_api_v2_workspace_templates_get**](docs/DefaultApi.md#list_templates_api_v2_workspace_templates_get) | **GET** /api/v2/workspace_templates/ | List Templates
*DefaultApi* | [**list_user_group_memberships_api_v2_user_groups_memberships_list_get**](docs/DefaultApi.md#list_user_group_memberships_api_v2_user_groups_memberships_list_get) | **GET** /api/v2/user_groups/memberships/list | List User Group Memberships
*DefaultApi* | [**list_user_groups_api_v2_user_groups_get**](docs/DefaultApi.md#list_user_groups_api_v2_user_groups_get) | **GET** /api/v2/user_groups/ | List User Groups
*DefaultApi* | [**list_values_api_v2_tags_values_get**](docs/DefaultApi.md#list_values_api_v2_tags_values_get) | **GET** /api/v2/tags/values | List Values
*DefaultApi* | [**list_volumes_in_schema_api_v2_data_catalogs_connections_connection_id_catalogs_catalog_id_schemas_schema_id_volumes_get**](docs/DefaultApi.md#list_volumes_in_schema_api_v2_data_catalogs_connections_connection_id_catalogs_catalog_id_schemas_schema_id_volumes_get) | **GET** /api/v2/data_catalogs/connections/{connection_id}/catalogs/{catalog_id}/schemas/{schema_id}/volumes | List Volumes In Schema
*DefaultApi* | [**list_workspace_templates_api_v2_experimental_workspaces_templates_get**](docs/DefaultApi.md#list_workspace_templates_api_v2_experimental_workspaces_templates_get) | **GET** /api/v2/experimental_workspaces/templates | List Workspace Templates
*DefaultApi* | [**list_workspaces_api_v2_experimental_workspaces_get**](docs/DefaultApi.md#list_workspaces_api_v2_experimental_workspaces_get) | **GET** /api/v2/experimental_workspaces/ | List Workspaces
*DefaultApi* | [**login_user_api_v2_users_login_post**](docs/DefaultApi.md#login_user_api_v2_users_login_post) | **POST** /api/v2/users/login | Login User
*DefaultApi* | [**logout_user_api_v2_users_logout_post**](docs/DefaultApi.md#logout_user_api_v2_users_logout_post) | **POST** /api/v2/users/logout | Logout User
*DefaultApi* | [**migrate_scim_permissions_api_v2_scim_migrate_permissions_post**](docs/DefaultApi.md#migrate_scim_permissions_api_v2_scim_migrate_permissions_post) | **POST** /api/v2/scim/migrate-permissions | Migrate Scim Permissions
*DefaultApi* | [**oauth_callback_api_v2_integrations_oauth_callback_get**](docs/DefaultApi.md#oauth_callback_api_v2_integrations_oauth_callback_get) | **GET** /api/v2/integrations/oauth/callback | Oauth Callback
*DefaultApi* | [**patch_workspace_api_v2_experimental_workspaces_workspace_id_patch**](docs/DefaultApi.md#patch_workspace_api_v2_experimental_workspaces_workspace_id_patch) | **PATCH** /api/v2/experimental_workspaces/{workspace_id} | Patch Workspace
*DefaultApi* | [**pause_cron_job_api_v2_experimental_cron_jobs_cron_job_id_pause_post**](docs/DefaultApi.md#pause_cron_job_api_v2_experimental_cron_jobs_cron_job_id_pause_post) | **POST** /api/v2/experimental_cron_jobs/{cron_job_id}/pause | Pause Cron Job
*DefaultApi* | [**produce_analytics_event_api_v2_analytics_post**](docs/DefaultApi.md#produce_analytics_event_api_v2_analytics_post) | **POST** /api/v2/analytics/ | Produce Analytics Event
*DefaultApi* | [**publish_api_v2_streams_publish_post**](docs/DefaultApi.md#publish_api_v2_streams_publish_post) | **POST** /api/v2/streams/publish | Publish
*DefaultApi* | [**publish_version_api_v2_workspace_templates_template_id_versions_version_id_publish_post**](docs/DefaultApi.md#publish_version_api_v2_workspace_templates_template_id_versions_version_id_publish_post) | **POST** /api/v2/workspace_templates/{template_id}/versions/{version_id}/publish | Publish Version
*DefaultApi* | [**push_cloud_overview_dashboard_api_v2_clouds_cloud_id_push_cloud_overview_dashboard_post**](docs/DefaultApi.md#push_cloud_overview_dashboard_api_v2_clouds_cloud_id_push_cloud_overview_dashboard_post) | **POST** /api/v2/clouds/{cloud_id}/push-cloud-overview-dashboard | Push Cloud Overview Dashboard
*DefaultApi* | [**put_job_wandb_run_details_api_v2_integrations_job_wandb_run_details_job_id_put**](docs/DefaultApi.md#put_job_wandb_run_details_api_v2_integrations_job_wandb_run_details_job_id_put) | **PUT** /api/v2/integrations/job_wandb_run_details/{job_id} | Put Job Wandb Run Details
*DefaultApi* | [**put_production_job_wandb_run_details_api_v2_integrations_production_job_wandb_run_details_production_job_id_put**](docs/DefaultApi.md#put_production_job_wandb_run_details_api_v2_integrations_production_job_wandb_run_details_production_job_id_put) | **PUT** /api/v2/integrations/production_job_wandb_run_details/{production_job_id} | Put Production Job Wandb Run Details
*DefaultApi* | [**put_session_cluster_config_with_session_idle_timeout_api_v2_sessions_session_id_cluster_config_with_session_idle_timeout_put**](docs/DefaultApi.md#put_session_cluster_config_with_session_idle_timeout_api_v2_sessions_session_id_cluster_config_with_session_idle_timeout_put) | **PUT** /api/v2/sessions/{session_id}/cluster_config_with_session_idle_timeout | Put Session Cluster Config With Session Idle Timeout
*DefaultApi* | [**put_workspace_proxied_dataplane_artifacts_api_v2_experimental_workspaces_workspace_id_proxied_dataplane_artifacts_put**](docs/DefaultApi.md#put_workspace_proxied_dataplane_artifacts_api_v2_experimental_workspaces_workspace_id_proxied_dataplane_artifacts_put) | **PUT** /api/v2/experimental_workspaces/{workspace_id}/proxied_dataplane_artifacts | Put Workspace Proxied Dataplane Artifacts
*DefaultApi* | [**put_workspace_wandb_run_details_api_v2_integrations_workspace_wandb_run_details_workspace_id_put**](docs/DefaultApi.md#put_workspace_wandb_run_details_api_v2_integrations_workspace_wandb_run_details_workspace_id_put) | **PUT** /api/v2/integrations/workspace_wandb_run_details/{workspace_id} | Put Workspace Wandb Run Details
*DefaultApi* | [**query_aggregated_logs_api_v2_logs_query_aggregated_logs_get**](docs/DefaultApi.md#query_aggregated_logs_api_v2_logs_query_aggregated_logs_get) | **GET** /api/v2/logs/query_aggregated_logs | Query Aggregated Logs
*DefaultApi* | [**query_api_v2_metrics_query_get**](docs/DefaultApi.md#query_api_v2_metrics_query_get) | **GET** /api/v2/metrics/query | Query
*DefaultApi* | [**query_range_api_v2_metrics_query_range_get**](docs/DefaultApi.md#query_range_api_v2_metrics_query_range_get) | **GET** /api/v2/metrics/query_range | Query Range
*DefaultApi* | [**receive_cli_usage_api_v2_cli_usage_post**](docs/DefaultApi.md#receive_cli_usage_api_v2_cli_usage_post) | **POST** /api/v2/cli_usage/ | Receive Cli Usage
*DefaultApi* | [**redirect_to_service_api_v2_sessions_cluster_id_services_get**](docs/DefaultApi.md#redirect_to_service_api_v2_sessions_cluster_id_services_get) | **GET** /api/v2/sessions/{cluster_id}/services | Redirect To Service
*DefaultApi* | [**redirect_to_tools_api_v2_services_v2_service_id_tools_get**](docs/DefaultApi.md#redirect_to_tools_api_v2_services_v2_service_id_tools_get) | **GET** /api/v2/services-v2/{service_id}/tools | Redirect To Tools
*DefaultApi* | [**register_api_v2_kubernetes_manager_register_post**](docs/DefaultApi.md#register_api_v2_kubernetes_manager_register_post) | **POST** /api/v2/kubernetes_manager/register | Register
*DefaultApi* | [**register_build_api_v2_anyscaled_register_build_post**](docs/DefaultApi.md#register_build_api_v2_anyscaled_register_build_post) | **POST** /api/v2/anyscaled/register_build | Register Build
*DefaultApi* | [**register_databricks_connection_api_v2_integrations_connections_databricks_post**](docs/DefaultApi.md#register_databricks_connection_api_v2_integrations_connections_databricks_post) | **POST** /api/v2/integrations/connections/databricks | Register Databricks Connection
*DefaultApi* | [**register_machine_api_v2_anyscaled_register_machine_post**](docs/DefaultApi.md#register_machine_api_v2_anyscaled_register_machine_post) | **POST** /api/v2/anyscaled/register_machine | Register Machine
*DefaultApi* | [**register_user_api_v2_users_post**](docs/DefaultApi.md#register_user_api_v2_users_post) | **POST** /api/v2/users/ | Register User
*DefaultApi* | [**register_v2_api_v2_anyscaled_register_v2_post**](docs/DefaultApi.md#register_v2_api_v2_anyscaled_register_v2_post) | **POST** /api/v2/anyscaled/register_v2 | Register V2
*DefaultApi* | [**remove_cloud_resource_api_v2_clouds_cloud_id_remove_resource_delete**](docs/DefaultApi.md#remove_cloud_resource_api_v2_clouds_cloud_id_remove_resource_delete) | **DELETE** /api/v2/clouds/{cloud_id}/remove_resource | Remove Cloud Resource
*DefaultApi* | [**remove_organization_collaborator_api_v2_organization_collaborators_identity_id_delete**](docs/DefaultApi.md#remove_organization_collaborator_api_v2_organization_collaborators_identity_id_delete) | **DELETE** /api/v2/organization_collaborators/{identity_id} | Remove Organization Collaborator
*DefaultApi* | [**request_email_magic_link_api_v2_users_email_magic_link_post**](docs/DefaultApi.md#request_email_magic_link_api_v2_users_email_magic_link_post) | **POST** /api/v2/users/email_magic_link | Request Email Magic Link
*DefaultApi* | [**request_password_reset_api_v2_users_request_password_reset_post**](docs/DefaultApi.md#request_password_reset_api_v2_users_request_password_reset_post) | **POST** /api/v2/users/request_password_reset | Request Password Reset
*DefaultApi* | [**reset_password_api_v2_users_reset_password_post**](docs/DefaultApi.md#reset_password_api_v2_users_reset_password_post) | **POST** /api/v2/users/reset_password | Reset Password
*DefaultApi* | [**restart_service_api_v2_services_v2_service_id_restart_post**](docs/DefaultApi.md#restart_service_api_v2_services_v2_service_id_restart_post) | **POST** /api/v2/services-v2/{service_id}/restart | Restart Service
*DefaultApi* | [**revoke_api_key_api_v2_users_api_keys_api_key_id_delete**](docs/DefaultApi.md#revoke_api_key_api_v2_users_api_keys_api_key_id_delete) | **DELETE** /api/v2/users/api_keys/{api_key_id} | Revoke Api Key
*DefaultApi* | [**revoke_api_key_for_admin_api_v2_users_admin_api_keys_api_key_id_delete**](docs/DefaultApi.md#revoke_api_key_for_admin_api_v2_users_admin_api_keys_api_key_id_delete) | **DELETE** /api/v2/users/admin/api_keys/{api_key_id} | Revoke Api Key For Admin
*DefaultApi* | [**revoke_api_keys_api_v2_users_api_keys_revoke_post**](docs/DefaultApi.md#revoke_api_keys_api_v2_users_api_keys_revoke_post) | **POST** /api/v2/users/api_keys/revoke | Revoke Api Keys
*DefaultApi* | [**revoke_api_keys_for_admin_api_v2_users_admin_api_keys_revoke_post**](docs/DefaultApi.md#revoke_api_keys_for_admin_api_v2_users_admin_api_keys_revoke_post) | **POST** /api/v2/users/admin/api_keys/revoke | Revoke Api Keys For Admin
*DefaultApi* | [**rollback_service_api_v2_services_v2_service_id_rollback_post**](docs/DefaultApi.md#rollback_service_api_v2_services_v2_service_id_rollback_post) | **POST** /api/v2/services-v2/{service_id}/rollback | Rollback Service
*DefaultApi* | [**rotate_api_key_api_v2_users_rotate_api_key_get**](docs/DefaultApi.md#rotate_api_key_api_v2_users_rotate_api_key_get) | **GET** /api/v2/users/rotate_api_key | Rotate Api Key
*DefaultApi* | [**rotate_api_key_for_user_api_v2_organization_collaborators_rotate_api_key_for_user_user_id_post**](docs/DefaultApi.md#rotate_api_key_for_user_api_v2_organization_collaborators_rotate_api_key_for_user_user_id_post) | **POST** /api/v2/organization_collaborators/rotate_api_key_for_user/{user_id} | Rotate Api Key For User
*DefaultApi* | [**saml_acs_api_v2_organizations_organization_id_saml_acs_post**](docs/DefaultApi.md#saml_acs_api_v2_organizations_organization_id_saml_acs_post) | **POST** /api/v2/organizations/{organization_id}/saml_acs | Saml Acs
*DefaultApi* | [**search_cloud_collaborators_api_v2_clouds_cloud_id_collaborators_users_search_post**](docs/DefaultApi.md#search_cloud_collaborators_api_v2_clouds_cloud_id_collaborators_users_search_post) | **POST** /api/v2/clouds/{cloud_id}/collaborators/users/search | Search Cloud Collaborators
*DefaultApi* | [**search_cluster_environments_api_v2_application_templates_search_post**](docs/DefaultApi.md#search_cluster_environments_api_v2_application_templates_search_post) | **POST** /api/v2/application_templates/search | Search Cluster Environments
*DefaultApi* | [**search_compute_templates_api_v2_compute_templates_search_post**](docs/DefaultApi.md#search_compute_templates_api_v2_compute_templates_search_post) | **POST** /api/v2/compute_templates/search | Search Compute Templates
*DefaultApi* | [**search_machine_pools_api_v2_machine_pools_search_post**](docs/DefaultApi.md#search_machine_pools_api_v2_machine_pools_search_post) | **POST** /api/v2/machine_pools/search | Search Machine Pools
*DefaultApi* | [**search_organization_collaborators_api_v2_organization_collaborators_search_post**](docs/DefaultApi.md#search_organization_collaborators_api_v2_organization_collaborators_search_post) | **POST** /api/v2/organization_collaborators/search | Search Organization Collaborators
*DefaultApi* | [**search_organization_user_groups_collaborators_api_v2_organization_user_groups_collaborators_search_post**](docs/DefaultApi.md#search_organization_user_groups_collaborators_api_v2_organization_user_groups_collaborators_search_post) | **POST** /api/v2/organization_user_groups_collaborators/search | Search Organization User Groups Collaborators
*DefaultApi* | [**search_resource_notifications_api_v2_resource_notifications_search_post**](docs/DefaultApi.md#search_resource_notifications_api_v2_resource_notifications_search_post) | **POST** /api/v2/resource_notifications/search | Search Resource Notifications
*DefaultApi* | [**search_resource_quotas_api_v2_resource_quotas_search_post**](docs/DefaultApi.md#search_resource_quotas_api_v2_resource_quotas_search_post) | **POST** /api/v2/resource_quotas/search | Search Resource Quotas
*DefaultApi* | [**search_support_requests_api_v2_support_requests_search_post**](docs/DefaultApi.md#search_support_requests_api_v2_support_requests_search_post) | **POST** /api/v2/support_requests/search | Search Support Requests
*DefaultApi* | [**search_tags_api_v2_tags_get**](docs/DefaultApi.md#search_tags_api_v2_tags_get) | **GET** /api/v2/tags/ | Search Tags
*DefaultApi* | [**set_resource_quota_status_api_v2_resource_quotas_resource_quota_id_status_patch**](docs/DefaultApi.md#set_resource_quota_status_api_v2_resource_quotas_resource_quota_id_status_patch) | **PATCH** /api/v2/resource_quotas/{resource_quota_id}/status | Set Resource Quota Status
*DefaultApi* | [**set_roles_api_v2_organization_collaborators_user_id_roles_put**](docs/DefaultApi.md#set_roles_api_v2_organization_collaborators_user_id_roles_put) | **PUT** /api/v2/organization_collaborators/{user_id}/roles | Set Roles
*DefaultApi* | [**show_one_time_password_source_api_v2_users_show_otp_source_post**](docs/DefaultApi.md#show_one_time_password_source_api_v2_users_show_otp_source_post) | **POST** /api/v2/users/show_otp_source | Show One Time Password Source
*DefaultApi* | [**sso_admin_link_api_v2_organizations_organization_id_sso_admin_link_get**](docs/DefaultApi.md#sso_admin_link_api_v2_organizations_organization_id_sso_admin_link_get) | **GET** /api/v2/organizations/{organization_id}/sso_admin_link | Sso Admin Link
*DefaultApi* | [**sso_login_info_api_v2_users_sso_login_info_get**](docs/DefaultApi.md#sso_login_info_api_v2_users_sso_login_info_get) | **GET** /api/v2/users/sso_login_info | Sso Login Info
*DefaultApi* | [**sso_login_test_api_v2_users_sso_login_test_get**](docs/DefaultApi.md#sso_login_test_api_v2_users_sso_login_test_get) | **GET** /api/v2/users/sso_login_test | Sso Login Test
*DefaultApi* | [**start_session_api_v2_sessions_session_id_start_post**](docs/DefaultApi.md#start_session_api_v2_sessions_session_id_start_post) | **POST** /api/v2/sessions/{session_id}/start | Start Session
*DefaultApi* | [**stop_session_api_v2_sessions_session_id_stop_post**](docs/DefaultApi.md#stop_session_api_v2_sessions_session_id_stop_post) | **POST** /api/v2/sessions/{session_id}/stop | Stop Session
*DefaultApi* | [**stripe_success_webhook_api_v2_organization_billing_stripe_success_webhook_post**](docs/DefaultApi.md#stripe_success_webhook_api_v2_organization_billing_stripe_success_webhook_post) | **POST** /api/v2/organization_billing/stripe_success_webhook | Stripe Success Webhook
*DefaultApi* | [**summarize_machine_pool_api_v2_machine_pools_summary_post**](docs/DefaultApi.md#summarize_machine_pool_api_v2_machine_pools_summary_post) | **POST** /api/v2/machine_pools/summary | Summarize Machine Pool
*DefaultApi* | [**sync_organization_with_metronome_api_v2_organization_billing_organization_id_sync_with_metronome_post**](docs/DefaultApi.md#sync_organization_with_metronome_api_v2_organization_billing_organization_id_sync_with_metronome_post) | **POST** /api/v2/organization_billing/{organization_id}/sync_with_metronome | Sync Organization With Metronome
*DefaultApi* | [**terminate_job_api_v2_decorated_ha_jobs_production_job_id_terminate_post**](docs/DefaultApi.md#terminate_job_api_v2_decorated_ha_jobs_production_job_id_terminate_post) | **POST** /api/v2/decorated_ha_jobs/{production_job_id}/terminate | Terminate Job
*DefaultApi* | [**terminate_job_queue_api_v2_job_queues_job_queue_id_terminate_post**](docs/DefaultApi.md#terminate_job_queue_api_v2_job_queues_job_queue_id_terminate_post) | **POST** /api/v2/job_queues/{job_queue_id}/terminate | Terminate Job Queue
*DefaultApi* | [**terminate_service_api_v2_services_v2_service_id_terminate_post**](docs/DefaultApi.md#terminate_service_api_v2_services_v2_service_id_terminate_post) | **POST** /api/v2/services-v2/{service_id}/terminate | Terminate Service
*DefaultApi* | [**terminate_system_cluster_api_v2_system_workload_cloud_id_terminate_post**](docs/DefaultApi.md#terminate_system_cluster_api_v2_system_workload_cloud_id_terminate_post) | **POST** /api/v2/system_workload/{cloud_id}/terminate | Terminate System Cluster
*DefaultApi* | [**test_saml_acs_api_v2_organizations_organization_id_test_saml_acs_post**](docs/DefaultApi.md#test_saml_acs_api_v2_organizations_organization_id_test_saml_acs_post) | **POST** /api/v2/organizations/{organization_id}/test_saml_acs | Test Saml Acs
*DefaultApi* | [**toggle_instance_usage_budget_is_enabled_api_v2_instance_usage_budgets_instance_usage_budget_id_toggle_is_enabled_post**](docs/DefaultApi.md#toggle_instance_usage_budget_is_enabled_api_v2_instance_usage_budgets_instance_usage_budget_id_toggle_is_enabled_post) | **POST** /api/v2/instance_usage_budgets/{instance_usage_budget_id}/toggle_is_enabled | Toggle Instance Usage Budget Is Enabled
*DefaultApi* | [**trigger_cron_job_api_v2_experimental_cron_jobs_cron_job_id_trigger_post**](docs/DefaultApi.md#trigger_cron_job_api_v2_experimental_cron_jobs_cron_job_id_trigger_post) | **POST** /api/v2/experimental_cron_jobs/{cron_job_id}/trigger | Trigger Cron Job
*DefaultApi* | [**try_claim_cloud_api_v2_aioa_cloud_waitlist_claim_cloud_post**](docs/DefaultApi.md#try_claim_cloud_api_v2_aioa_cloud_waitlist_claim_cloud_post) | **POST** /api/v2/aioa_cloud_waitlist/claim_cloud | Try Claim Cloud
*DefaultApi* | [**try_login_api_v2_users_try_login_post**](docs/DefaultApi.md#try_login_api_v2_users_try_login_post) | **POST** /api/v2/users/try-login | Try Login
*DefaultApi* | [**try_login_workos_api_v2_users_try_login_auth_code_post**](docs/DefaultApi.md#try_login_workos_api_v2_users_try_login_auth_code_post) | **POST** /api/v2/users/try-login-auth-code | Try Login Workos
*DefaultApi* | [**unpublish_template_api_v2_workspace_templates_template_id_unpublish_post**](docs/DefaultApi.md#unpublish_template_api_v2_workspace_templates_template_id_unpublish_post) | **POST** /api/v2/workspace_templates/{template_id}/unpublish | Unpublish Template
*DefaultApi* | [**update_cloud_auto_add_user_api_v2_clouds_cloud_id_auto_add_user_put**](docs/DefaultApi.md#update_cloud_auto_add_user_api_v2_clouds_cloud_id_auto_add_user_put) | **PUT** /api/v2/clouds/{cloud_id}/auto_add_user | Update Cloud Auto Add User
*DefaultApi* | [**update_cloud_deployment_config_api_v2_clouds_cloud_id_deployment_cloud_deployment_id_config_put**](docs/DefaultApi.md#update_cloud_deployment_config_api_v2_clouds_cloud_id_deployment_cloud_deployment_id_config_put) | **PUT** /api/v2/clouds/{cloud_id}/deployment/{cloud_deployment_id}/config | Update Cloud Deployment Config
*DefaultApi* | [**update_cloud_lineage_tracking_enabled_api_v2_clouds_cloud_id_lineage_tracking_enabled_put**](docs/DefaultApi.md#update_cloud_lineage_tracking_enabled_api_v2_clouds_cloud_id_lineage_tracking_enabled_put) | **PUT** /api/v2/clouds/{cloud_id}/lineage_tracking_enabled | Update Cloud Lineage Tracking Enabled
*DefaultApi* | [**update_cloud_resources_api_v2_clouds_cloud_id_resources_put**](docs/DefaultApi.md#update_cloud_resources_api_v2_clouds_cloud_id_resources_put) | **PUT** /api/v2/clouds/{cloud_id}/resources | Update Cloud Resources
*DefaultApi* | [**update_cloud_state_api_v2_clouds_cloud_id_state_put**](docs/DefaultApi.md#update_cloud_state_api_v2_clouds_cloud_id_state_put) | **PUT** /api/v2/clouds/{cloud_id}/state | Update Cloud State
*DefaultApi* | [**update_cloud_with_cloud_resource_api_v2_clouds_with_cloud_resource_gcp_router_cloud_id_put**](docs/DefaultApi.md#update_cloud_with_cloud_resource_api_v2_clouds_with_cloud_resource_gcp_router_cloud_id_put) | **PUT** /api/v2/clouds_with_cloud_resource_gcp_router/{cloud_id} | Update Cloud With Cloud Resource
*DefaultApi* | [**update_cloud_with_cloud_resource_api_v2_clouds_with_cloud_resource_router_cloud_id_put**](docs/DefaultApi.md#update_cloud_with_cloud_resource_api_v2_clouds_with_cloud_resource_router_cloud_id_put) | **PUT** /api/v2/clouds_with_cloud_resource_router/{cloud_id} | Update Cloud With Cloud Resource
*DefaultApi* | [**update_customer_aggregated_logs_config_api_v2_clouds_cloud_id_update_customer_aggregated_logs_config_put**](docs/DefaultApi.md#update_customer_aggregated_logs_config_api_v2_clouds_cloud_id_update_customer_aggregated_logs_config_put) | **PUT** /api/v2/clouds/{cloud_id}/update_customer_aggregated_logs_config | Update Customer Aggregated Logs Config
*DefaultApi* | [**update_default_cloud_api_v2_organizations_update_default_cloud_post**](docs/DefaultApi.md#update_default_cloud_api_v2_organizations_update_default_cloud_post) | **POST** /api/v2/organizations/update_default_cloud | Update Default Cloud
*DefaultApi* | [**update_dns_api_v2_dns_post**](docs/DefaultApi.md#update_dns_api_v2_dns_post) | **POST** /api/v2/dns/ | Update Dns
*DefaultApi* | [**update_event_processing_status_api_v2_workos_events_event_id_status_put**](docs/DefaultApi.md#update_event_processing_status_api_v2_workos_events_event_id_status_put) | **PUT** /api/v2/workos/events/{event_id}/status | Update Event Processing Status
*DefaultApi* | [**update_instance_usage_budget_api_v2_instance_usage_budgets_instance_usage_budget_id_put**](docs/DefaultApi.md#update_instance_usage_budget_api_v2_instance_usage_budgets_instance_usage_budget_id_put) | **PUT** /api/v2/instance_usage_budgets/{instance_usage_budget_id} | Update Instance Usage Budget
*DefaultApi* | [**update_job_queue_api_v2_job_queues_job_queue_id_put**](docs/DefaultApi.md#update_job_queue_api_v2_job_queues_job_queue_id_put) | **PUT** /api/v2/job_queues/{job_queue_id} | Update Job Queue
*DefaultApi* | [**update_job_queue_config_api_v2_decorated_ha_jobs_production_job_id_update_job_queue_config_put**](docs/DefaultApi.md#update_job_queue_config_api_v2_decorated_ha_jobs_production_job_id_update_job_queue_config_put) | **PUT** /api/v2/decorated_ha_jobs/{production_job_id}/update_job_queue_config | Update Job Queue Config
*DefaultApi* | [**update_machine_pool_api_v2_machine_pools_update_post**](docs/DefaultApi.md#update_machine_pool_api_v2_machine_pools_update_post) | **POST** /api/v2/machine_pools/update | Update Machine Pool
*DefaultApi* | [**update_payment_info_api_v2_organization_billing_update_payment_info_post**](docs/DefaultApi.md#update_payment_info_api_v2_organization_billing_update_payment_info_post) | **POST** /api/v2/organization_billing/update_payment_info | Update Payment Info
*DefaultApi* | [**update_resource_notification_api_v2_resource_notifications_resource_notification_id_put**](docs/DefaultApi.md#update_resource_notification_api_v2_resource_notifications_resource_notification_id_put) | **PUT** /api/v2/resource_notifications/{resource_notification_id} | Update Resource Notification
*DefaultApi* | [**update_resource_policy_api_v2_policy_resource_type_resource_id_put**](docs/DefaultApi.md#update_resource_policy_api_v2_policy_resource_type_resource_id_put) | **PUT** /api/v2/policy/{resource_type}/{resource_id} | Update Resource Policy
*DefaultApi* | [**update_resource_quota_api_v2_resource_quotas_resource_quota_id_patch**](docs/DefaultApi.md#update_resource_quota_api_v2_resource_quotas_resource_quota_id_patch) | **PATCH** /api/v2/resource_quotas/{resource_quota_id} | Update Resource Quota
*DefaultApi* | [**update_system_cluster_config_api_v2_clouds_cloud_id_update_system_cluster_config_put**](docs/DefaultApi.md#update_system_cluster_config_api_v2_clouds_cloud_id_update_system_cluster_config_put) | **PUT** /api/v2/clouds/{cloud_id}/update_system_cluster_config | Update System Cluster Config
*DefaultApi* | [**update_template_api_v2_workspace_templates_template_id_put**](docs/DefaultApi.md#update_template_api_v2_workspace_templates_template_id_put) | **PUT** /api/v2/workspace_templates/{template_id} | Update Template
*DefaultApi* | [**upgrade_multi_version_weights_api_v2_services_v2_service_id_update_weights_put**](docs/DefaultApi.md#upgrade_multi_version_weights_api_v2_services_v2_service_id_update_weights_put) | **PUT** /api/v2/services-v2/{service_id}/update_weights | Upgrade Multi Version Weights
*DefaultApi* | [**upload_session_command_logs_api_v2_session_commands_session_command_id_upload_logs_post**](docs/DefaultApi.md#upload_session_command_logs_api_v2_session_commands_session_command_id_upload_logs_post) | **POST** /api/v2/session_commands/{session_command_id}/upload_logs | Upload Session Command Logs
*DefaultApi* | [**upsert_billing_version_api_v2_organization_billing_billing_versions_put**](docs/DefaultApi.md#upsert_billing_version_api_v2_organization_billing_billing_versions_put) | **PUT** /api/v2/organization_billing/billing_versions | Upsert Billing Version
*DefaultApi* | [**upsert_resource_tags_api_v2_tags_resource_put**](docs/DefaultApi.md#upsert_resource_tags_api_v2_tags_resource_put) | **PUT** /api/v2/tags/resource | Upsert Resource Tags
*DefaultApi* | [**upsert_support_request_for_user_organization_api_v2_support_requests_support_request_put**](docs/DefaultApi.md#upsert_support_request_for_user_organization_api_v2_support_requests_support_request_put) | **PUT** /api/v2/support_requests/support_request | Upsert Support Request For User Organization
*DefaultApi* | [**use_workos_api_v2_workos_use_workos_get**](docs/DefaultApi.md#use_workos_api_v2_workos_use_workos_get) | **GET** /api/v2/workos/use_workos | Use Workos
*DefaultApi* | [**user_resend_email_api_v2_users_resend_email_post**](docs/DefaultApi.md#user_resend_email_api_v2_users_resend_email_post) | **POST** /api/v2/users/resend_email | User Resend Email
*DefaultApi* | [**user_verify_api_v2_users_verify_token_get**](docs/DefaultApi.md#user_verify_api_v2_users_verify_token_get) | **GET** /api/v2/users/verify/{token} | User Verify
*DefaultApi* | [**validate_api_v2_authentication_validate_post**](docs/DefaultApi.md#validate_api_v2_authentication_validate_post) | **POST** /api/v2/authentication/validate | Validate
*DefaultApi* | [**validate_invite_code_api_v2_users_validate_invite_code_invite_code_post**](docs/DefaultApi.md#validate_invite_code_api_v2_users_validate_invite_code_invite_code_post) | **POST** /api/v2/users/validate_invite_code/{invite_code} | Validate Invite Code
*DefaultApi* | [**validate_one_time_password_api_v2_users_validate_otp_token_post**](docs/DefaultApi.md#validate_one_time_password_api_v2_users_validate_otp_token_post) | **POST** /api/v2/users/validate_otp_token | Validate One Time Password
*DefaultApi* | [**verify_access_api_v2_cloudsverify_access_cloud_id_get**](docs/DefaultApi.md#verify_access_api_v2_cloudsverify_access_cloud_id_get) | **GET** /api/v2/cloudsverify_access/{cloud_id} | Verify Access
*DefaultApi* | [**verify_reset_password_token_api_v2_users_reset_password_token_get**](docs/DefaultApi.md#verify_reset_password_token_api_v2_users_reset_password_token_get) | **GET** /api/v2/users/reset_password/{token} | Verify Reset Password Token
*DefaultApi* | [**workos_callback_api_v2_workos_callback_get**](docs/DefaultApi.md#workos_callback_api_v2_workos_callback_get) | **GET** /api/v2/workos/callback | Workos Callback
*DefaultApi* | [**workos_verify_email_code_api_v2_workos_email_verification_verify_post**](docs/DefaultApi.md#workos_verify_email_code_api_v2_workos_email_verification_verify_post) | **POST** /api/v2/workos/email_verification/verify | Workos Verify Email Code


## Documentation For Models

 - [AWSConfig](docs/AWSConfig.md)
 - [AWSMemoryDBClusterConfig](docs/AWSMemoryDBClusterConfig.md)
 - [AccessConfig](docs/AccessConfig.md)
 - [ActorExitDetailGroupAggregate](docs/ActorExitDetailGroupAggregate.md)
 - [ActorExitDetailGroupAggregateResponse](docs/ActorExitDetailGroupAggregateResponse.md)
 - [ActorGroupedAggregateMetrics](docs/ActorGroupedAggregateMetrics.md)
 - [ActorJobGroupAggregate](docs/ActorJobGroupAggregate.md)
 - [ActorJobGroupAggregateResponse](docs/ActorJobGroupAggregateResponse.md)
 - [ActorNameGroupAggregate](docs/ActorNameGroupAggregate.md)
 - [ActorNameGroupAggregateResponse](docs/ActorNameGroupAggregateResponse.md)
 - [ActorState](docs/ActorState.md)
 - [ActorStatus](docs/ActorStatus.md)
 - [ActorSummary](docs/ActorSummary.md)
 - [ActorTableConfig](docs/ActorTableConfig.md)
 - [ActorTableResponse](docs/ActorTableResponse.md)
 - [ActorTableRow](docs/ActorTableRow.md)
 - [ActorsummaryResponse](docs/ActorsummaryResponse.md)
 - [AdminCreateUser](docs/AdminCreateUser.md)
 - [AdminCreatedUser](docs/AdminCreatedUser.md)
 - [AdmincreateduserListResponse](docs/AdmincreateduserListResponse.md)
 - [AggregatedUsage](docs/AggregatedUsage.md)
 - [AggregatedUsageQuery](docs/AggregatedUsageQuery.md)
 - [AggregatedusageResponse](docs/AggregatedusageResponse.md)
 - [AioaCloudWaitlistRecord](docs/AioaCloudWaitlistRecord.md)
 - [AioacloudwaitlistrecordResponse](docs/AioacloudwaitlistrecordResponse.md)
 - [AlertIssueType](docs/AlertIssueType.md)
 - [AnyscaleAWSAccount](docs/AnyscaleAWSAccount.md)
 - [AnyscaleServiceAccount](docs/AnyscaleServiceAccount.md)
 - [AnyscaleawsaccountResponse](docs/AnyscaleawsaccountResponse.md)
 - [AnyscaledCredentialResponse](docs/AnyscaledCredentialResponse.md)
 - [AnyscaledcredentialresponseResponse](docs/AnyscaledcredentialresponseResponse.md)
 - [AnyscaleserviceaccountResponse](docs/AnyscaleserviceaccountResponse.md)
 - [ApiKeyInfo](docs/ApiKeyInfo.md)
 - [ApiKeyParameters](docs/ApiKeyParameters.md)
 - [ApikeyinfoListResponse](docs/ApikeyinfoListResponse.md)
 - [AppConfig](docs/AppConfig.md)
 - [AppConfigConfigSchema](docs/AppConfigConfigSchema.md)
 - [AppconfigListResponse](docs/AppconfigListResponse.md)
 - [AppconfigResponse](docs/AppconfigResponse.md)
 - [ApplicationType](docs/ApplicationType.md)
 - [AppliedSnapshot](docs/AppliedSnapshot.md)
 - [ApplyAutoscalingConfigUpdateModel](docs/ApplyAutoscalingConfigUpdateModel.md)
 - [ApplyMultiVersionUpdateWeightsUpdateModel](docs/ApplyMultiVersionUpdateWeightsUpdateModel.md)
 - [ApplyProductionServiceMultiVersionV2Model](docs/ApplyProductionServiceMultiVersionV2Model.md)
 - [ApplyProductionServiceV2Model](docs/ApplyProductionServiceV2Model.md)
 - [ApplyVersionWeightUpdateModel](docs/ApplyVersionWeightUpdateModel.md)
 - [ArchiveStatus](docs/ArchiveStatus.md)
 - [AttachMachinePoolToCloudRequest](docs/AttachMachinePoolToCloudRequest.md)
 - [AttachmachinepooltocloudresponseResponse](docs/AttachmachinepooltocloudresponseResponse.md)
 - [AuthResourceType](docs/AuthResourceType.md)
 - [AwsRegionAndZones](docs/AwsRegionAndZones.md)
 - [AwsRegionInfo](docs/AwsRegionInfo.md)
 - [AwsregionandzonesResponse](docs/AwsregionandzonesResponse.md)
 - [AzureConfig](docs/AzureConfig.md)
 - [AzureOperatorAudience](docs/AzureOperatorAudience.md)
 - [AzureoperatoraudienceResponse](docs/AzureoperatoraudienceResponse.md)
 - [BASEIMAGESENUM](docs/BASEIMAGESENUM.md)
 - [BackendServerApiProductModelsCatalogClientModelsTableMetadata](docs/BackendServerApiProductModelsCatalogClientModelsTableMetadata.md)
 - [BackendServerApiProductModelsDataCatalogsTableMetadata](docs/BackendServerApiProductModelsDataCatalogsTableMetadata.md)
 - [BaseJobStatus](docs/BaseJobStatus.md)
 - [BatchResponseBatchedResultOrganizationInvitationBase](docs/BatchResponseBatchedResultOrganizationInvitationBase.md)
 - [BatchedResultOrganizationInvitationBase](docs/BatchedResultOrganizationInvitationBase.md)
 - [BillingVersionCode](docs/BillingVersionCode.md)
 - [Binding](docs/Binding.md)
 - [BodyAwsMarketplaceRegistrationApiV2OrganizationBillingAwsMarketplaceRegistrationPost](docs/BodyAwsMarketplaceRegistrationApiV2OrganizationBillingAwsMarketplaceRegistrationPost.md)
 - [Build](docs/Build.md)
 - [BuildLogResponse](docs/BuildLogResponse.md)
 - [BuildRegistration](docs/BuildRegistration.md)
 - [BuildResponse](docs/BuildResponse.md)
 - [BuildStatus](docs/BuildStatus.md)
 - [BuildlogresponseResponse](docs/BuildlogresponseResponse.md)
 - [CLIUsagePayload](docs/CLIUsagePayload.md)
 - [CatalogMetadata](docs/CatalogMetadata.md)
 - [ChangePasswordParams](docs/ChangePasswordParams.md)
 - [CleanupLeakedGrafanaDashboardResponse](docs/CleanupLeakedGrafanaDashboardResponse.md)
 - [CleanupleakedgrafanadashboardresponseResponse](docs/CleanupleakedgrafanadashboardresponseResponse.md)
 - [CloneExperimentalWorkspace](docs/CloneExperimentalWorkspace.md)
 - [Cloud](docs/Cloud.md)
 - [CloudAnalyticsEvent](docs/CloudAnalyticsEvent.md)
 - [CloudAnalyticsEventCloudProviderError](docs/CloudAnalyticsEventCloudProviderError.md)
 - [CloudAnalyticsEventCloudResource](docs/CloudAnalyticsEventCloudResource.md)
 - [CloudAnalyticsEventCommandName](docs/CloudAnalyticsEventCommandName.md)
 - [CloudAnalyticsEventError](docs/CloudAnalyticsEventError.md)
 - [CloudAnalyticsEventName](docs/CloudAnalyticsEventName.md)
 - [CloudCollaborator](docs/CloudCollaborator.md)
 - [CloudCollaboratorValue](docs/CloudCollaboratorValue.md)
 - [CloudCollaboratorsQuery](docs/CloudCollaboratorsQuery.md)
 - [CloudConfig](docs/CloudConfig.md)
 - [CloudDataBucketAccessMode](docs/CloudDataBucketAccessMode.md)
 - [CloudDataBucketFileType](docs/CloudDataBucketFileType.md)
 - [CloudDataBucketPresignedUploadInfo](docs/CloudDataBucketPresignedUploadInfo.md)
 - [CloudDataBucketPresignedUploadRequest](docs/CloudDataBucketPresignedUploadRequest.md)
 - [CloudDataBucketPresignedUploadScheme](docs/CloudDataBucketPresignedUploadScheme.md)
 - [CloudDataBucketPresignedUrlRequest](docs/CloudDataBucketPresignedUrlRequest.md)
 - [CloudDataBucketPresignedUrlResponse](docs/CloudDataBucketPresignedUrlResponse.md)
 - [CloudDataBucketPresignedUrlScheme](docs/CloudDataBucketPresignedUrlScheme.md)
 - [CloudDataBucketRequestScope](docs/CloudDataBucketRequestScope.md)
 - [CloudDeployment](docs/CloudDeployment.md)
 - [CloudDeploymentComputeConfig](docs/CloudDeploymentComputeConfig.md)
 - [CloudDeploymentConfig](docs/CloudDeploymentConfig.md)
 - [CloudListResponse](docs/CloudListResponse.md)
 - [CloudNameOptions](docs/CloudNameOptions.md)
 - [CloudOverviewDashboard](docs/CloudOverviewDashboard.md)
 - [CloudPermissionRemoval](docs/CloudPermissionRemoval.md)
 - [CloudPermissionSummary](docs/CloudPermissionSummary.md)
 - [CloudProjectCollaborator](docs/CloudProjectCollaborator.md)
 - [CloudProjectCollaboratorValue](docs/CloudProjectCollaboratorValue.md)
 - [CloudProvider](docs/CloudProvider.md)
 - [CloudProviders](docs/CloudProviders.md)
 - [CloudRegionAndZones](docs/CloudRegionAndZones.md)
 - [CloudRegionInfo](docs/CloudRegionInfo.md)
 - [CloudResource](docs/CloudResource.md)
 - [CloudResourceAdditionalInstanceTypes](docs/CloudResourceAdditionalInstanceTypes.md)
 - [CloudResourceGCP](docs/CloudResourceGCP.md)
 - [CloudResponse](docs/CloudResponse.md)
 - [CloudState](docs/CloudState.md)
 - [CloudStatus](docs/CloudStatus.md)
 - [CloudType](docs/CloudType.md)
 - [CloudTypes](docs/CloudTypes.md)
 - [CloudVersion](docs/CloudVersion.md)
 - [CloudWaitlistStatus](docs/CloudWaitlistStatus.md)
 - [CloudWithCloudResource](docs/CloudWithCloudResource.md)
 - [CloudWithCloudResourceGCP](docs/CloudWithCloudResourceGCP.md)
 - [CloudcollaboratorListResponse](docs/CloudcollaboratorListResponse.md)
 - [ClouddatabucketpresigneduploadinfoResponse](docs/ClouddatabucketpresigneduploadinfoResponse.md)
 - [ClouddatabucketpresignedurlresponseResponse](docs/ClouddatabucketpresignedurlresponseResponse.md)
 - [ClouddeploymentResponse](docs/ClouddeploymentResponse.md)
 - [ClouddeploymentconfigResponse](docs/ClouddeploymentconfigResponse.md)
 - [CloudoverviewdashboardResponse](docs/CloudoverviewdashboardResponse.md)
 - [CloudregionandzonesResponse](docs/CloudregionandzonesResponse.md)
 - [CloudresourceResponse](docs/CloudresourceResponse.md)
 - [CloudresourceadditionalinstancetypesListResponse](docs/CloudresourceadditionalinstancetypesListResponse.md)
 - [CloudresourcegcpResponse](docs/CloudresourcegcpResponse.md)
 - [CloudwithcloudresourceResponse](docs/CloudwithcloudresourceResponse.md)
 - [CloudwithcloudresourcegcpResponse](docs/CloudwithcloudresourcegcpResponse.md)
 - [ClusterAuthResponse](docs/ClusterAuthResponse.md)
 - [ClusterDashboardNode](docs/ClusterDashboardNode.md)
 - [ClusterEnvironmentsQuery](docs/ClusterEnvironmentsQuery.md)
 - [ClusterEvent](docs/ClusterEvent.md)
 - [ClusterEventSource](docs/ClusterEventSource.md)
 - [ClusterEventsOutput](docs/ClusterEventsOutput.md)
 - [ClusterManagementStackVersions](docs/ClusterManagementStackVersions.md)
 - [ClusterOperation](docs/ClusterOperation.md)
 - [ClusterOperationType](docs/ClusterOperationType.md)
 - [ClusterState](docs/ClusterState.md)
 - [ClusterStatus](docs/ClusterStatus.md)
 - [ClusterStatusDetails](docs/ClusterStatusDetails.md)
 - [ClusterauthresponseResponse](docs/ClusterauthresponseResponse.md)
 - [ClusterdashboardnodeListResponse](docs/ClusterdashboardnodeListResponse.md)
 - [ClusterdashboardnodeResponse](docs/ClusterdashboardnodeResponse.md)
 - [ClustereventListResponse](docs/ClustereventListResponse.md)
 - [ClustereventsoutputResponse](docs/ClustereventsoutputResponse.md)
 - [ClusteroperationResponse](docs/ClusteroperationResponse.md)
 - [CollaboratorType](docs/CollaboratorType.md)
 - [ColumnInfo](docs/ColumnInfo.md)
 - [CommitLedgerItemType](docs/CommitLedgerItemType.md)
 - [CommitLedgerRecordV2](docs/CommitLedgerRecordV2.md)
 - [ComplexityLevel](docs/ComplexityLevel.md)
 - [ComputeNodeType](docs/ComputeNodeType.md)
 - [ComputeStack](docs/ComputeStack.md)
 - [ComputeTemplate](docs/ComputeTemplate.md)
 - [ComputeTemplateConfig](docs/ComputeTemplateConfig.md)
 - [ComputeTemplateQuery](docs/ComputeTemplateQuery.md)
 - [ComputetemplateResponse](docs/ComputetemplateResponse.md)
 - [ComputetemplateconfigResponse](docs/ComputetemplateconfigResponse.md)
 - [ConnectionMetadata](docs/ConnectionMetadata.md)
 - [ConnectionType](docs/ConnectionType.md)
 - [CreateAioaCloudWaitlist](docs/CreateAioaCloudWaitlist.md)
 - [CreateAnalyticsEvent](docs/CreateAnalyticsEvent.md)
 - [CreateAppConfig](docs/CreateAppConfig.md)
 - [CreateAppConfigConfigurationSchema](docs/CreateAppConfigConfigurationSchema.md)
 - [CreateBYODAppConfig](docs/CreateBYODAppConfig.md)
 - [CreateBYODAppConfigConfigurationSchema](docs/CreateBYODAppConfigConfigurationSchema.md)
 - [CreateBYODBuild](docs/CreateBYODBuild.md)
 - [CreateBillingVersion](docs/CreateBillingVersion.md)
 - [CreateBugReportResponse](docs/CreateBugReportResponse.md)
 - [CreateBuild](docs/CreateBuild.md)
 - [CreateCloudCollaborator](docs/CreateCloudCollaborator.md)
 - [CreateCloudResource](docs/CreateCloudResource.md)
 - [CreateCloudResourceGCP](docs/CreateCloudResourceGCP.md)
 - [CreateClusterComputeConfig](docs/CreateClusterComputeConfig.md)
 - [CreateComputeTemplate](docs/CreateComputeTemplate.md)
 - [CreateComputeTemplateConfig](docs/CreateComputeTemplateConfig.md)
 - [CreateDataset](docs/CreateDataset.md)
 - [CreateExperimentalWorkspace](docs/CreateExperimentalWorkspace.md)
 - [CreateInstanceUsageBudget](docs/CreateInstanceUsageBudget.md)
 - [CreateInternalProductionJob](docs/CreateInternalProductionJob.md)
 - [CreateJobQueueConfig](docs/CreateJobQueueConfig.md)
 - [CreateJobQueueRequests](docs/CreateJobQueueRequests.md)
 - [CreateMachinePoolRequest](docs/CreateMachinePoolRequest.md)
 - [CreateMachinePoolResponse](docs/CreateMachinePoolResponse.md)
 - [CreateMachineRequest](docs/CreateMachineRequest.md)
 - [CreateMachineResponse](docs/CreateMachineResponse.md)
 - [CreateMetronomeWebhookNotification](docs/CreateMetronomeWebhookNotification.md)
 - [CreateNotificationChannelRecord](docs/CreateNotificationChannelRecord.md)
 - [CreateOTPReturnApiModel](docs/CreateOTPReturnApiModel.md)
 - [CreateOrganizationConfiguration](docs/CreateOrganizationConfiguration.md)
 - [CreateOrganizationInvitation](docs/CreateOrganizationInvitation.md)
 - [CreateProductionJobConfig](docs/CreateProductionJobConfig.md)
 - [CreateResourceNotification](docs/CreateResourceNotification.md)
 - [CreateResourceQuota](docs/CreateResourceQuota.md)
 - [CreateSchedule](docs/CreateSchedule.md)
 - [CreateUser](docs/CreateUser.md)
 - [CreateUserProjectCollaborator](docs/CreateUserProjectCollaborator.md)
 - [CreateUserProjectCollaboratorValue](docs/CreateUserProjectCollaboratorValue.md)
 - [CreateWorkspaceFromTemplate](docs/CreateWorkspaceFromTemplate.md)
 - [CreateWorkspaceTemplate](docs/CreateWorkspaceTemplate.md)
 - [CreateWorkspaceTemplateVersion](docs/CreateWorkspaceTemplateVersion.md)
 - [CreatebugreportresponseResponse](docs/CreatebugreportresponseResponse.md)
 - [CreatecomputetemplateconfigResponse](docs/CreatecomputetemplateconfigResponse.md)
 - [CreatemachinepoolresponseResponse](docs/CreatemachinepoolresponseResponse.md)
 - [CreatemachineresponseResponse](docs/CreatemachineresponseResponse.md)
 - [CreateotpreturnapimodelResponse](docs/CreateotpreturnapimodelResponse.md)
 - [CreditGrantRecordV2](docs/CreditGrantRecordV2.md)
 - [CreditLedgerItemType](docs/CreditLedgerItemType.md)
 - [CreditLedgerRecordV2](docs/CreditLedgerRecordV2.md)
 - [CreditRecordCommitV2](docs/CreditRecordCommitV2.md)
 - [CreditRecordCreditV2](docs/CreditRecordCreditV2.md)
 - [CreditType](docs/CreditType.md)
 - [CreditsV2](docs/CreditsV2.md)
 - [CustomerAlertStatus](docs/CustomerAlertStatus.md)
 - [DashboardPanel](docs/DashboardPanel.md)
 - [DataCatalog](docs/DataCatalog.md)
 - [DataCatalogConnection](docs/DataCatalogConnection.md)
 - [DataCatalogConnectionStatus](docs/DataCatalogConnectionStatus.md)
 - [DataCatalogObjectType](docs/DataCatalogObjectType.md)
 - [DataCatalogProvider](docs/DataCatalogProvider.md)
 - [DataCatalogSchema](docs/DataCatalogSchema.md)
 - [DataCatalogTable](docs/DataCatalogTable.md)
 - [DataCatalogVolume](docs/DataCatalogVolume.md)
 - [DatabricksConnectionConfig](docs/DatabricksConnectionConfig.md)
 - [DatabricksConnectionInfo](docs/DatabricksConnectionInfo.md)
 - [DatabricksConnectionResponse](docs/DatabricksConnectionResponse.md)
 - [DatabricksRegisterRequest](docs/DatabricksRegisterRequest.md)
 - [DatabricksconnectioninfoResponse](docs/DatabricksconnectioninfoResponse.md)
 - [DatabricksconnectionresponseResponse](docs/DatabricksconnectionresponseResponse.md)
 - [DatacatalogListResponse](docs/DatacatalogListResponse.md)
 - [DatacatalogconnectionListResponse](docs/DatacatalogconnectionListResponse.md)
 - [DatacatalogschemaListResponse](docs/DatacatalogschemaListResponse.md)
 - [DatacatalogtableListResponse](docs/DatacatalogtableListResponse.md)
 - [DatacatalogvolumeListResponse](docs/DatacatalogvolumeListResponse.md)
 - [DataplaneServices](docs/DataplaneServices.md)
 - [Dataset](docs/Dataset.md)
 - [DatasetDag](docs/DatasetDag.md)
 - [DatasetDagResponse](docs/DatasetDagResponse.md)
 - [DatasetJobs](docs/DatasetJobs.md)
 - [DatasetListResponse](docs/DatasetListResponse.md)
 - [DatasetMetadata](docs/DatasetMetadata.md)
 - [DatasetMetadataResponse](docs/DatasetMetadataResponse.md)
 - [DatasetMetrics](docs/DatasetMetrics.md)
 - [DatasetMetricsResponse](docs/DatasetMetricsResponse.md)
 - [DatasetResponse](docs/DatasetResponse.md)
 - [DatasetState](docs/DatasetState.md)
 - [DatasetUpload](docs/DatasetUpload.md)
 - [DatasetuploadResponse](docs/DatasetuploadResponse.md)
 - [DecoratedApplicationTemplate](docs/DecoratedApplicationTemplate.md)
 - [DecoratedBuild](docs/DecoratedBuild.md)
 - [DecoratedCloudResource](docs/DecoratedCloudResource.md)
 - [DecoratedComputeTemplate](docs/DecoratedComputeTemplate.md)
 - [DecoratedComputeTemplateConfig](docs/DecoratedComputeTemplateConfig.md)
 - [DecoratedInteractiveSession](docs/DecoratedInteractiveSession.md)
 - [DecoratedJob](docs/DecoratedJob.md)
 - [DecoratedJobQueue](docs/DecoratedJobQueue.md)
 - [DecoratedListServiceAPIModel](docs/DecoratedListServiceAPIModel.md)
 - [DecoratedProductionJob](docs/DecoratedProductionJob.md)
 - [DecoratedProductionJobStateTransition](docs/DecoratedProductionJobStateTransition.md)
 - [DecoratedProductionServiceV2APIModel](docs/DecoratedProductionServiceV2APIModel.md)
 - [DecoratedProductionServiceV2VersionAPIModel](docs/DecoratedProductionServiceV2VersionAPIModel.md)
 - [DecoratedSchedule](docs/DecoratedSchedule.md)
 - [DecoratedServeDeployment](docs/DecoratedServeDeployment.md)
 - [DecoratedServiceEventAPIModel](docs/DecoratedServiceEventAPIModel.md)
 - [DecoratedSession](docs/DecoratedSession.md)
 - [DecoratedSupportRequest](docs/DecoratedSupportRequest.md)
 - [DecoratedUnifiedJob](docs/DecoratedUnifiedJob.md)
 - [DecoratedapplicationtemplateListResponse](docs/DecoratedapplicationtemplateListResponse.md)
 - [DecoratedapplicationtemplateResponse](docs/DecoratedapplicationtemplateResponse.md)
 - [DecoratedbuildListResponse](docs/DecoratedbuildListResponse.md)
 - [DecoratedbuildResponse](docs/DecoratedbuildResponse.md)
 - [DecoratedcloudresourceListResponse](docs/DecoratedcloudresourceListResponse.md)
 - [DecoratedcloudresourceResponse](docs/DecoratedcloudresourceResponse.md)
 - [DecoratedcomputetemplateListResponse](docs/DecoratedcomputetemplateListResponse.md)
 - [DecoratedcomputetemplateResponse](docs/DecoratedcomputetemplateResponse.md)
 - [DecoratedinteractivesessionListResponse](docs/DecoratedinteractivesessionListResponse.md)
 - [DecoratedinteractivesessionResponse](docs/DecoratedinteractivesessionResponse.md)
 - [DecoratedjobResponse](docs/DecoratedjobResponse.md)
 - [DecoratedjobqueueListResponse](docs/DecoratedjobqueueListResponse.md)
 - [DecoratedjobqueueResponse](docs/DecoratedjobqueueResponse.md)
 - [DecoratedlistserviceapimodelListResponse](docs/DecoratedlistserviceapimodelListResponse.md)
 - [DecoratedproductionjobListResponse](docs/DecoratedproductionjobListResponse.md)
 - [DecoratedproductionjobResponse](docs/DecoratedproductionjobResponse.md)
 - [DecoratedproductionjobstatetransitionListResponse](docs/DecoratedproductionjobstatetransitionListResponse.md)
 - [Decoratedproductionservicev2ApimodelResponse](docs/Decoratedproductionservicev2ApimodelResponse.md)
 - [Decoratedproductionservicev2VersionapimodelListResponse](docs/Decoratedproductionservicev2VersionapimodelListResponse.md)
 - [Decoratedproductionservicev2VersionapimodelResponse](docs/Decoratedproductionservicev2VersionapimodelResponse.md)
 - [DecoratedscheduleListResponse](docs/DecoratedscheduleListResponse.md)
 - [DecoratedscheduleResponse](docs/DecoratedscheduleResponse.md)
 - [DecoratedservedeploymentListResponse](docs/DecoratedservedeploymentListResponse.md)
 - [DecoratedservedeploymentResponse](docs/DecoratedservedeploymentResponse.md)
 - [DecoratedserviceeventapimodelListResponse](docs/DecoratedserviceeventapimodelListResponse.md)
 - [DecoratedsessionListResponse](docs/DecoratedsessionListResponse.md)
 - [DecoratedsessionResponse](docs/DecoratedsessionResponse.md)
 - [DecoratedsupportrequestListResponse](docs/DecoratedsupportrequestListResponse.md)
 - [DecoratedsupportrequestResponse](docs/DecoratedsupportrequestResponse.md)
 - [DecoratedunifiedjobListResponse](docs/DecoratedunifiedjobListResponse.md)
 - [DeleteMachinePoolRequest](docs/DeleteMachinePoolRequest.md)
 - [DeleteMachineRequest](docs/DeleteMachineRequest.md)
 - [DeleteResourceTagsRequest](docs/DeleteResourceTagsRequest.md)
 - [DeletedCount](docs/DeletedCount.md)
 - [DeletedPlatformFineTunedModel](docs/DeletedPlatformFineTunedModel.md)
 - [DeletedcountResponse](docs/DeletedcountResponse.md)
 - [DeletedplatformfinetunedmodelResponse](docs/DeletedplatformfinetunedmodelResponse.md)
 - [DeletemachinepoolresponseResponse](docs/DeletemachinepoolresponseResponse.md)
 - [DeploymentInfraResponse](docs/DeploymentInfraResponse.md)
 - [DeploymentinfraresponseResponse](docs/DeploymentinfraresponseResponse.md)
 - [DescribeMachinePoolMachinesFilters](docs/DescribeMachinePoolMachinesFilters.md)
 - [DescribeMachinePoolMachinesRequest](docs/DescribeMachinePoolMachinesRequest.md)
 - [DescribeMachinePoolRequest](docs/DescribeMachinePoolRequest.md)
 - [DescribeMachinePoolRequestsFilters](docs/DescribeMachinePoolRequestsFilters.md)
 - [DescribeMachinePoolRequestsRequest](docs/DescribeMachinePoolRequestsRequest.md)
 - [DescribeMachinePoolResponse](docs/DescribeMachinePoolResponse.md)
 - [DescribeMachinePoolWorkloadsFilters](docs/DescribeMachinePoolWorkloadsFilters.md)
 - [DescribeMachinePoolWorkloadsRequest](docs/DescribeMachinePoolWorkloadsRequest.md)
 - [DescribeSystemWorkloadResponse](docs/DescribeSystemWorkloadResponse.md)
 - [DescribemachinepoolresponseResponse](docs/DescribemachinepoolresponseResponse.md)
 - [DescribesystemworkloadresponseResponse](docs/DescribesystemworkloadresponseResponse.md)
 - [DetachMachinePoolFromCloudRequest](docs/DetachMachinePoolFromCloudRequest.md)
 - [DetachmachinepoolfromcloudresponseResponse](docs/DetachmachinepoolfromcloudresponseResponse.md)
 - [DirectorySync](docs/DirectorySync.md)
 - [DirectorySyncReadiness](docs/DirectorySyncReadiness.md)
 - [DirectorysyncreadinessResponse](docs/DirectorysyncreadinessResponse.md)
 - [DomainVerification](docs/DomainVerification.md)
 - [EditableCloudResource](docs/EditableCloudResource.md)
 - [EditableCloudResourceGCP](docs/EditableCloudResourceGCP.md)
 - [EmailVerificationRequest](docs/EmailVerificationRequest.md)
 - [EmailVerificationResponse](docs/EmailVerificationResponse.md)
 - [EmailverificationresponseResponse](docs/EmailverificationresponseResponse.md)
 - [EntityType](docs/EntityType.md)
 - [Error](docs/Error.md)
 - [EventLevel](docs/EventLevel.md)
 - [ExecuteCommandResponse](docs/ExecuteCommandResponse.md)
 - [ExecuteInteractiveCommandOptions](docs/ExecuteInteractiveCommandOptions.md)
 - [ExecutecommandresponseResponse](docs/ExecutecommandresponseResponse.md)
 - [ExperimentalWorkspace](docs/ExperimentalWorkspace.md)
 - [ExperimentalWorkspacesSortField](docs/ExperimentalWorkspacesSortField.md)
 - [ExperimentalworkspaceListResponse](docs/ExperimentalworkspaceListResponse.md)
 - [ExperimentalworkspaceResponse](docs/ExperimentalworkspaceResponse.md)
 - [ExternalTerminalCommand](docs/ExternalTerminalCommand.md)
 - [FeatureFlagResponse](docs/FeatureFlagResponse.md)
 - [FeatureflagresponseResponse](docs/FeatureflagresponseResponse.md)
 - [FileStorage](docs/FileStorage.md)
 - [FineTuneType](docs/FineTuneType.md)
 - [FineTunedModel](docs/FineTunedModel.md)
 - [FinetunedmodelListResponse](docs/FinetunedmodelListResponse.md)
 - [FinetunedmodelResponse](docs/FinetunedmodelResponse.md)
 - [GCPConfig](docs/GCPConfig.md)
 - [GCPFileStoreConfig](docs/GCPFileStoreConfig.md)
 - [GCPMemorystoreInstanceConfig](docs/GCPMemorystoreInstanceConfig.md)
 - [GPUUsage](docs/GPUUsage.md)
 - [GetOrCreateBuildFromImageUriRequest](docs/GetOrCreateBuildFromImageUriRequest.md)
 - [GlobalWorkspaceTemplate](docs/GlobalWorkspaceTemplate.md)
 - [GlobalworkspacetemplateListResponse](docs/GlobalworkspacetemplateListResponse.md)
 - [GrafanaDashboard](docs/GrafanaDashboard.md)
 - [GrpcProtocolConfig](docs/GrpcProtocolConfig.md)
 - [HTTPValidationError](docs/HTTPValidationError.md)
 - [HaJobErrorTypes](docs/HaJobErrorTypes.md)
 - [HaJobEventOrigin](docs/HaJobEventOrigin.md)
 - [HaJobGoalStates](docs/HaJobGoalStates.md)
 - [HaJobStates](docs/HaJobStates.md)
 - [HaJobType](docs/HaJobType.md)
 - [HaJobsSortField](docs/HaJobsSortField.md)
 - [HeadIp](docs/HeadIp.md)
 - [HeadipResponse](docs/HeadipResponse.md)
 - [HttpProtocolConfig](docs/HttpProtocolConfig.md)
 - [IKnowResponse](docs/IKnowResponse.md)
 - [IKnowTimeSeriesEvent](docs/IKnowTimeSeriesEvent.md)
 - [IdleTerminationStatus](docs/IdleTerminationStatus.md)
 - [ImportClusterEnvironment](docs/ImportClusterEnvironment.md)
 - [InstanceUsageBudget](docs/InstanceUsageBudget.md)
 - [InstanceUsageBudgetEvaluationPeriod](docs/InstanceUsageBudgetEvaluationPeriod.md)
 - [InstanceUsageBudgetUnit](docs/InstanceUsageBudgetUnit.md)
 - [InstanceusagebudgetListResponse](docs/InstanceusagebudgetListResponse.md)
 - [InstanceusagebudgetResponse](docs/InstanceusagebudgetResponse.md)
 - [IntegrationDetails](docs/IntegrationDetails.md)
 - [InternalProductionJob](docs/InternalProductionJob.md)
 - [InternalproductionjobResponse](docs/InternalproductionjobResponse.md)
 - [JobAccess](docs/JobAccess.md)
 - [JobDetails](docs/JobDetails.md)
 - [JobEventFields](docs/JobEventFields.md)
 - [JobQueue](docs/JobQueue.md)
 - [JobQueueConfig](docs/JobQueueConfig.md)
 - [JobQueueExecutionMode](docs/JobQueueExecutionMode.md)
 - [JobQueueSortDirective](docs/JobQueueSortDirective.md)
 - [JobQueueSortField](docs/JobQueueSortField.md)
 - [JobQueueSpec](docs/JobQueueSpec.md)
 - [JobQueueState](docs/JobQueueState.md)
 - [JobQueueTerminationResponse](docs/JobQueueTerminationResponse.md)
 - [JobQueuesQuery](docs/JobQueuesQuery.md)
 - [JobReport](docs/JobReport.md)
 - [JobRunType](docs/JobRunType.md)
 - [JobStateLogLevelTypes](docs/JobStateLogLevelTypes.md)
 - [JobWithReport](docs/JobWithReport.md)
 - [JobqueueResponse](docs/JobqueueResponse.md)
 - [JobqueueterminationresponseResponse](docs/JobqueueterminationresponseResponse.md)
 - [JobsSortField](docs/JobsSortField.md)
 - [JobwithreportListResponse](docs/JobwithreportListResponse.md)
 - [JsonPatchOperation](docs/JsonPatchOperation.md)
 - [KubernetesConfig](docs/KubernetesConfig.md)
 - [KubernetesManagerRegistrationRequest](docs/KubernetesManagerRegistrationRequest.md)
 - [KubernetesManagerRegistrationResponse](docs/KubernetesManagerRegistrationResponse.md)
 - [KubernetesmanagerregistrationresponseResponse](docs/KubernetesmanagerregistrationresponseResponse.md)
 - [LBResource](docs/LBResource.md)
 - [LbresourceResponse](docs/LbresourceResponse.md)
 - [LineageArtifact](docs/LineageArtifact.md)
 - [LineageArtifactSortField](docs/LineageArtifactSortField.md)
 - [LineageArtifactType](docs/LineageArtifactType.md)
 - [LineageDirection](docs/LineageDirection.md)
 - [LineageGraph](docs/LineageGraph.md)
 - [LineageGraphNode](docs/LineageGraphNode.md)
 - [LineageNodeType](docs/LineageNodeType.md)
 - [LineageWorkload](docs/LineageWorkload.md)
 - [LineageWorkloadSortField](docs/LineageWorkloadSortField.md)
 - [LineageWorkloadType](docs/LineageWorkloadType.md)
 - [LineageartifactListResponse](docs/LineageartifactListResponse.md)
 - [LineageartifactResponse](docs/LineageartifactResponse.md)
 - [LineagegraphResponse](docs/LineagegraphResponse.md)
 - [LineageworkloadListResponse](docs/LineageworkloadListResponse.md)
 - [LineageworkloadResponse](docs/LineageworkloadResponse.md)
 - [ListDatabricksConnections](docs/ListDatabricksConnections.md)
 - [ListMachinePoolsResponse](docs/ListMachinePoolsResponse.md)
 - [ListMachinesResponse](docs/ListMachinesResponse.md)
 - [ListRaySessionsResponse](docs/ListRaySessionsResponse.md)
 - [ListResourceNotificationsQuery](docs/ListResourceNotificationsQuery.md)
 - [ListResourceQuotasQuery](docs/ListResourceQuotasQuery.md)
 - [ListResponseMetadata](docs/ListResponseMetadata.md)
 - [ListUserGroupMembershipsResult](docs/ListUserGroupMembershipsResult.md)
 - [ListmachinepoolsresponseResponse](docs/ListmachinepoolsresponseResponse.md)
 - [ListmachinesresponseResponse](docs/ListmachinesresponseResponse.md)
 - [ListraysessionsresponseResponse](docs/ListraysessionsresponseResponse.md)
 - [ListusergroupmembershipsresultResponse](docs/ListusergroupmembershipsresultResponse.md)
 - [LogDownloadConfig](docs/LogDownloadConfig.md)
 - [LogDownloadRequest](docs/LogDownloadRequest.md)
 - [LogDownloadResult](docs/LogDownloadResult.md)
 - [LogFileChunk](docs/LogFileChunk.md)
 - [LogFilter](docs/LogFilter.md)
 - [LogItem](docs/LogItem.md)
 - [LogItemBatch](docs/LogItemBatch.md)
 - [LogdownloadresultResponse](docs/LogdownloadresultResponse.md)
 - [LoginUserParams](docs/LoginUserParams.md)
 - [LogitembatchResponse](docs/LogitembatchResponse.md)
 - [LogsOutput](docs/LogsOutput.md)
 - [LogsoutputResponse](docs/LogsoutputResponse.md)
 - [LongRunningWorkload](docs/LongRunningWorkload.md)
 - [LongrunningworkloadListResponse](docs/LongrunningworkloadListResponse.md)
 - [MachineAllocationState](docs/MachineAllocationState.md)
 - [MachineConnectionState](docs/MachineConnectionState.md)
 - [MachineInfo](docs/MachineInfo.md)
 - [MachineLaunchFailure](docs/MachineLaunchFailure.md)
 - [MachinePool](docs/MachinePool.md)
 - [MachinePoolSearchQuery](docs/MachinePoolSearchQuery.md)
 - [MachinePoolSearchResult](docs/MachinePoolSearchResult.md)
 - [MachineStateInfo](docs/MachineStateInfo.md)
 - [MachineTypePartitionFilter](docs/MachineTypePartitionFilter.md)
 - [MachinepoolsearchresultListResponse](docs/MachinepoolsearchresultListResponse.md)
 - [MachinestateinfoListResponse](docs/MachinestateinfoListResponse.md)
 - [Metric](docs/Metric.md)
 - [MetricsQueryResponse](docs/MetricsQueryResponse.md)
 - [MetricsqueryresponseResponse](docs/MetricsqueryresponseResponse.md)
 - [MetronomeCustomerInfoModel](docs/MetronomeCustomerInfoModel.md)
 - [MetronomeDashboardType](docs/MetronomeDashboardType.md)
 - [MetronomecustomerinfomodelListResponse](docs/MetronomecustomerinfomodelListResponse.md)
 - [MetronomecustomerinfomodelResponse](docs/MetronomecustomerinfomodelResponse.md)
 - [MiniBuild](docs/MiniBuild.md)
 - [MiniCloud](docs/MiniCloud.md)
 - [MiniCluster](docs/MiniCluster.md)
 - [MiniComputeTemplate](docs/MiniComputeTemplate.md)
 - [MiniComputeTemplateConfig](docs/MiniComputeTemplateConfig.md)
 - [MiniJobRun](docs/MiniJobRun.md)
 - [MiniNamespace](docs/MiniNamespace.md)
 - [MiniOrganization](docs/MiniOrganization.md)
 - [MiniProductionJob](docs/MiniProductionJob.md)
 - [MiniProject](docs/MiniProject.md)
 - [MiniRuntimeEnvironment](docs/MiniRuntimeEnvironment.md)
 - [MiniSchedule](docs/MiniSchedule.md)
 - [MiniUser](docs/MiniUser.md)
 - [MinibuildListResponse](docs/MinibuildListResponse.md)
 - [MinicomputetemplateListResponse](docs/MinicomputetemplateListResponse.md)
 - [NFSMountTarget](docs/NFSMountTarget.md)
 - [NetworkingMode](docs/NetworkingMode.md)
 - [NodeMetrics](docs/NodeMetrics.md)
 - [NodeMetricsResponse](docs/NodeMetricsResponse.md)
 - [NodeRegistrationAWS](docs/NodeRegistrationAWS.md)
 - [NodeRegistrationGCP](docs/NodeRegistrationGCP.md)
 - [NodeRegistrationK8S](docs/NodeRegistrationK8S.md)
 - [NodeRegistrationProvisioned](docs/NodeRegistrationProvisioned.md)
 - [NodeRegistrationV2](docs/NodeRegistrationV2.md)
 - [NodeStatus](docs/NodeStatus.md)
 - [NodeType](docs/NodeType.md)
 - [NodemetricsresponseResponse](docs/NodemetricsresponseResponse.md)
 - [NotificationChannelEmailConfig](docs/NotificationChannelEmailConfig.md)
 - [NotificationChannelSlackConfig](docs/NotificationChannelSlackConfig.md)
 - [NotificationChannelWebhookConfig](docs/NotificationChannelWebhookConfig.md)
 - [OauthAuthUrlResponse](docs/OauthAuthUrlResponse.md)
 - [ObjectStorage](docs/ObjectStorage.md)
 - [OperationError](docs/OperationError.md)
 - [OperationProgress](docs/OperationProgress.md)
 - [OperationResult](docs/OperationResult.md)
 - [OperatorBranch](docs/OperatorBranch.md)
 - [OperatorCheckResult](docs/OperatorCheckResult.md)
 - [OperatorCheckStatus](docs/OperatorCheckStatus.md)
 - [OperatorEvent](docs/OperatorEvent.md)
 - [OperatorEventResponse](docs/OperatorEventResponse.md)
 - [OperatorEventType](docs/OperatorEventType.md)
 - [OperatorId](docs/OperatorId.md)
 - [OperatorMetadata](docs/OperatorMetadata.md)
 - [OperatorMetrics](docs/OperatorMetrics.md)
 - [OperatorStatus](docs/OperatorStatus.md)
 - [OperatorStatusDetails](docs/OperatorStatusDetails.md)
 - [OrgOwner](docs/OrgOwner.md)
 - [OrgPermissionChange](docs/OrgPermissionChange.md)
 - [Organization](docs/Organization.md)
 - [OrganizationAdditionalRole](docs/OrganizationAdditionalRole.md)
 - [OrganizationBaseRole](docs/OrganizationBaseRole.md)
 - [OrganizationCollaborator](docs/OrganizationCollaborator.md)
 - [OrganizationCollaboratorsQuery](docs/OrganizationCollaboratorsQuery.md)
 - [OrganizationConfiguration](docs/OrganizationConfiguration.md)
 - [OrganizationConfigurationResponse](docs/OrganizationConfigurationResponse.md)
 - [OrganizationInvitation](docs/OrganizationInvitation.md)
 - [OrganizationInvitationBase](docs/OrganizationInvitationBase.md)
 - [OrganizationMarketingQuestions](docs/OrganizationMarketingQuestions.md)
 - [OrganizationPermissionLevel](docs/OrganizationPermissionLevel.md)
 - [OrganizationSummary](docs/OrganizationSummary.md)
 - [OrganizationUsageAlert](docs/OrganizationUsageAlert.md)
 - [OrganizationUsageAlertSeverity](docs/OrganizationUsageAlertSeverity.md)
 - [OrganizationUserGroupsCollaborator](docs/OrganizationUserGroupsCollaborator.md)
 - [OrganizationUserGroupsCollaboratorsQuery](docs/OrganizationUserGroupsCollaboratorsQuery.md)
 - [OrganizationcollaboratorListResponse](docs/OrganizationcollaboratorListResponse.md)
 - [OrganizationconfigurationListResponse](docs/OrganizationconfigurationListResponse.md)
 - [OrganizationconfigurationresponseResponse](docs/OrganizationconfigurationresponseResponse.md)
 - [OrganizationinvitationListResponse](docs/OrganizationinvitationListResponse.md)
 - [OrganizationinvitationResponse](docs/OrganizationinvitationResponse.md)
 - [OrganizationinvitationbaseResponse](docs/OrganizationinvitationbaseResponse.md)
 - [OrganizationusagealertListResponse](docs/OrganizationusagealertListResponse.md)
 - [OrganizationusergroupscollaboratorListResponse](docs/OrganizationusergroupscollaboratorListResponse.md)
 - [PageQuery](docs/PageQuery.md)
 - [PartitionInfo](docs/PartitionInfo.md)
 - [PauseSchedule](docs/PauseSchedule.md)
 - [PermissionCheckRequest](docs/PermissionCheckRequest.md)
 - [PermissionCheckResponse](docs/PermissionCheckResponse.md)
 - [PermissionLevel](docs/PermissionLevel.md)
 - [PermissionType](docs/PermissionType.md)
 - [PermissioncheckresponseResponse](docs/PermissioncheckresponseResponse.md)
 - [PhysicalResources](docs/PhysicalResources.md)
 - [PlanStatus](docs/PlanStatus.md)
 - [PolicyResponse](docs/PolicyResponse.md)
 - [PolicySyncStatus](docs/PolicySyncStatus.md)
 - [PolicyresponseResponse](docs/PolicyresponseResponse.md)
 - [PresignedUrlResponse](docs/PresignedUrlResponse.md)
 - [ProductionJob](docs/ProductionJob.md)
 - [ProductionJobConfig](docs/ProductionJobConfig.md)
 - [ProductionJobEvent](docs/ProductionJobEvent.md)
 - [ProductionJobEventScopeFilter](docs/ProductionJobEventScopeFilter.md)
 - [ProductionJobStateTransition](docs/ProductionJobStateTransition.md)
 - [ProductionjobResponse](docs/ProductionjobResponse.md)
 - [ProductionjobeventListResponse](docs/ProductionjobeventListResponse.md)
 - [Project](docs/Project.md)
 - [ProjectBase](docs/ProjectBase.md)
 - [ProjectCollaborator](docs/ProjectCollaborator.md)
 - [ProjectCollaboratorValue](docs/ProjectCollaboratorValue.md)
 - [ProjectDefaultSessionName](docs/ProjectDefaultSessionName.md)
 - [ProjectListResponse](docs/ProjectListResponse.md)
 - [ProjectPermissionRemoval](docs/ProjectPermissionRemoval.md)
 - [ProjectPermissionSummary](docs/ProjectPermissionSummary.md)
 - [ProjectResponse](docs/ProjectResponse.md)
 - [ProjectbaseResponse](docs/ProjectbaseResponse.md)
 - [ProjectcollaboratorListResponse](docs/ProjectcollaboratorListResponse.md)
 - [ProjectdefaultsessionnameResponse](docs/ProjectdefaultsessionnameResponse.md)
 - [ProjectsSortField](docs/ProjectsSortField.md)
 - [Protocols](docs/Protocols.md)
 - [PublishedFilter](docs/PublishedFilter.md)
 - [PythonModules](docs/PythonModules.md)
 - [Quota](docs/Quota.md)
 - [RayGCSExternalStorageConfig](docs/RayGCSExternalStorageConfig.md)
 - [RayRuntimeEnvConfig](docs/RayRuntimeEnvConfig.md)
 - [RaySession](docs/RaySession.md)
 - [ReadBillingVersion](docs/ReadBillingVersion.md)
 - [ReadbillingversionListResponse](docs/ReadbillingversionListResponse.md)
 - [RedactionRequest](docs/RedactionRequest.md)
 - [RedactionResult](docs/RedactionResult.md)
 - [ReplicaDetails](docs/ReplicaDetails.md)
 - [ReplicaState](docs/ReplicaState.md)
 - [RequestEmailMagicLinkResponse](docs/RequestEmailMagicLinkResponse.md)
 - [RequestOTPReturnApiModel](docs/RequestOTPReturnApiModel.md)
 - [RequestPasswordResetParams](docs/RequestPasswordResetParams.md)
 - [RequestStateInfo](docs/RequestStateInfo.md)
 - [RequestemailmagiclinkresponseResponse](docs/RequestemailmagiclinkresponseResponse.md)
 - [RequestotpreturnapimodelResponse](docs/RequestotpreturnapimodelResponse.md)
 - [RequeststateinfoListResponse](docs/RequeststateinfoListResponse.md)
 - [ResetPasswordParams](docs/ResetPasswordParams.md)
 - [ResourceAlertEventType](docs/ResourceAlertEventType.md)
 - [ResourceNotification](docs/ResourceNotification.md)
 - [ResourcePolicyItem](docs/ResourcePolicyItem.md)
 - [ResourceQuota](docs/ResourceQuota.md)
 - [ResourceQuotaStatus](docs/ResourceQuotaStatus.md)
 - [ResourceTagRecord](docs/ResourceTagRecord.md)
 - [ResourceTagResourceType](docs/ResourceTagResourceType.md)
 - [ResourceTagsList](docs/ResourceTagsList.md)
 - [ResourceType](docs/ResourceType.md)
 - [ResourcenotificationListResponse](docs/ResourcenotificationListResponse.md)
 - [ResourcenotificationResponse](docs/ResourcenotificationResponse.md)
 - [ResourcepolicyitemListResponse](docs/ResourcepolicyitemListResponse.md)
 - [ResourcequotaListResponse](docs/ResourcequotaListResponse.md)
 - [ResourcequotaResponse](docs/ResourcequotaResponse.md)
 - [Resources](docs/Resources.md)
 - [ResourcetagslistResponse](docs/ResourcetagslistResponse.md)
 - [RevokeApiKeysRequest](docs/RevokeApiKeysRequest.md)
 - [RevokeApiKeysResponse](docs/RevokeApiKeysResponse.md)
 - [RevokeapikeysresponseResponse](docs/RevokeapikeysresponseResponse.md)
 - [RollbackServiceModel](docs/RollbackServiceModel.md)
 - [RolloutStrategy](docs/RolloutStrategy.md)
 - [RunAttemptStatus](docs/RunAttemptStatus.md)
 - [RunStatus](docs/RunStatus.md)
 - [S3DownloadLocation](docs/S3DownloadLocation.md)
 - [SCIMMigrationResult](docs/SCIMMigrationResult.md)
 - [SSOConfig](docs/SSOConfig.md)
 - [SSOConnection](docs/SSOConnection.md)
 - [SSOConnectionState](docs/SSOConnectionState.md)
 - [SSOLoginInfo](docs/SSOLoginInfo.md)
 - [SSOMode](docs/SSOMode.md)
 - [SUPPORTEDBASEIMAGESENUM](docs/SUPPORTEDBASEIMAGESENUM.md)
 - [ScheduleConfig](docs/ScheduleConfig.md)
 - [SchedulerInfo](docs/SchedulerInfo.md)
 - [SchemaMetadata](docs/SchemaMetadata.md)
 - [ScimListUserPermissionsResult](docs/ScimListUserPermissionsResult.md)
 - [ScimUserFacingRole](docs/ScimUserFacingRole.md)
 - [ScimlistuserpermissionsresultResponse](docs/ScimlistuserpermissionsresultResponse.md)
 - [ScimmigrationresultResponse](docs/ScimmigrationresultResponse.md)
 - [ServeDeploymentGrafanaDashboardStatus](docs/ServeDeploymentGrafanaDashboardStatus.md)
 - [ServeDeploymentState](docs/ServeDeploymentState.md)
 - [ServerSessionToken](docs/ServerSessionToken.md)
 - [ServersessiontokenResponse](docs/ServersessiontokenResponse.md)
 - [ServiceConfig](docs/ServiceConfig.md)
 - [ServiceEventCurrentState](docs/ServiceEventCurrentState.md)
 - [ServiceEventFields](docs/ServiceEventFields.md)
 - [ServiceEventOrigin](docs/ServiceEventOrigin.md)
 - [ServiceEventScope](docs/ServiceEventScope.md)
 - [ServiceEventScopeFilter](docs/ServiceEventScopeFilter.md)
 - [ServiceEventType](docs/ServiceEventType.md)
 - [ServiceEventVerboseMessageModel](docs/ServiceEventVerboseMessageModel.md)
 - [ServiceGoalStates](docs/ServiceGoalStates.md)
 - [ServiceObservabilityUrls](docs/ServiceObservabilityUrls.md)
 - [ServiceSortField](docs/ServiceSortField.md)
 - [ServiceType](docs/ServiceType.md)
 - [ServiceVersionSortField](docs/ServiceVersionSortField.md)
 - [ServiceVersionState](docs/ServiceVersionState.md)
 - [ServiceeventverbosemessagemodelListResponse](docs/ServiceeventverbosemessagemodelListResponse.md)
 - [Session](docs/Session.md)
 - [SessionAccess](docs/SessionAccess.md)
 - [SessionCommand](docs/SessionCommand.md)
 - [SessionCommandFinishOptions](docs/SessionCommandFinishOptions.md)
 - [SessionCommandId](docs/SessionCommandId.md)
 - [SessionCommandTypes](docs/SessionCommandTypes.md)
 - [SessionListResponse](docs/SessionListResponse.md)
 - [SessionResponse](docs/SessionResponse.md)
 - [SessionSshKey](docs/SessionSshKey.md)
 - [SessionStartingUpData](docs/SessionStartingUpData.md)
 - [SessionState](docs/SessionState.md)
 - [SessionStateData](docs/SessionStateData.md)
 - [SessionStoppingData](docs/SessionStoppingData.md)
 - [SessioncommandListResponse](docs/SessioncommandListResponse.md)
 - [SessioncommandidResponse](docs/SessioncommandidResponse.md)
 - [SessionsSortField](docs/SessionsSortField.md)
 - [SessionsshkeyResponse](docs/SessionsshkeyResponse.md)
 - [SetOrganizationRoles](docs/SetOrganizationRoles.md)
 - [ShowOTPSourceReturnApiModel](docs/ShowOTPSourceReturnApiModel.md)
 - [ShowotpsourcereturnapimodelResponse](docs/ShowotpsourcereturnapimodelResponse.md)
 - [SortByClause](docs/SortByClause.md)
 - [SortOrder](docs/SortOrder.md)
 - [SsoconfigResponse](docs/SsoconfigResponse.md)
 - [SsologininfoResponse](docs/SsologininfoResponse.md)
 - [StartSessionOptions](docs/StartSessionOptions.md)
 - [StopSessionOptions](docs/StopSessionOptions.md)
 - [StreamPublishRequest](docs/StreamPublishRequest.md)
 - [SubnetIdWithAvailabilityZoneAWS](docs/SubnetIdWithAvailabilityZoneAWS.md)
 - [SummarizeMachinePoolRequest](docs/SummarizeMachinePoolRequest.md)
 - [SummarizeMachinePoolResponse](docs/SummarizeMachinePoolResponse.md)
 - [SummarizemachinepoolresponseResponse](docs/SummarizemachinepoolresponseResponse.md)
 - [SupportRequestsQuery](docs/SupportRequestsQuery.md)
 - [SystemWorkloadName](docs/SystemWorkloadName.md)
 - [TableDataPreview](docs/TableDataPreview.md)
 - [TableRedactionResult](docs/TableRedactionResult.md)
 - [TagKey](docs/TagKey.md)
 - [TagKeyValue](docs/TagKeyValue.md)
 - [TagSearchIn](docs/TagSearchIn.md)
 - [TagValue](docs/TagValue.md)
 - [TagkeyListResponse](docs/TagkeyListResponse.md)
 - [TagkeyvalueListResponse](docs/TagkeyvalueListResponse.md)
 - [TagvalueListResponse](docs/TagvalueListResponse.md)
 - [TaskAttempts](docs/TaskAttempts.md)
 - [TaskExceptionGroupAggregate](docs/TaskExceptionGroupAggregate.md)
 - [TaskExceptionGroupAggregateResponse](docs/TaskExceptionGroupAggregateResponse.md)
 - [TaskFunctionNameGroupAggregate](docs/TaskFunctionNameGroupAggregate.md)
 - [TaskFunctionNameGroupAggregateResponse](docs/TaskFunctionNameGroupAggregateResponse.md)
 - [TaskGroupedAggregateMetrics](docs/TaskGroupedAggregateMetrics.md)
 - [TaskJobGroupAggregate](docs/TaskJobGroupAggregate.md)
 - [TaskJobGroupAggregateResponse](docs/TaskJobGroupAggregateResponse.md)
 - [TaskState](docs/TaskState.md)
 - [TaskSummary](docs/TaskSummary.md)
 - [TaskSummaryConfig](docs/TaskSummaryConfig.md)
 - [TaskTableConfig](docs/TaskTableConfig.md)
 - [TaskTableResponse](docs/TaskTableResponse.md)
 - [TaskTableRow](docs/TaskTableRow.md)
 - [TaskType](docs/TaskType.md)
 - [TasksummaryResponse](docs/TasksummaryResponse.md)
 - [TextQuery](docs/TextQuery.md)
 - [Tool](docs/Tool.md)
 - [TracingConfig](docs/TracingConfig.md)
 - [TrainResources](docs/TrainResources.md)
 - [TrainRun](docs/TrainRun.md)
 - [TrainRunAttempt](docs/TrainRunAttempt.md)
 - [TrainWorker](docs/TrainWorker.md)
 - [TrainrunListResponse](docs/TrainrunListResponse.md)
 - [TryLoginEmailResponse](docs/TryLoginEmailResponse.md)
 - [TryLoginWorkOSResponse](docs/TryLoginWorkOSResponse.md)
 - [TryloginemailresponseResponse](docs/TryloginemailresponseResponse.md)
 - [TryloginworkosresponseResponse](docs/TryloginworkosresponseResponse.md)
 - [UXInstance](docs/UXInstance.md)
 - [UnifiedEvent](docs/UnifiedEvent.md)
 - [UnifiedJobSortField](docs/UnifiedJobSortField.md)
 - [UnifiedJobStatus](docs/UnifiedJobStatus.md)
 - [UnifiedJobType](docs/UnifiedJobType.md)
 - [UnifiedOriginFilter](docs/UnifiedOriginFilter.md)
 - [UnifiedeventListResponse](docs/UnifiedeventListResponse.md)
 - [UpdateCloudCollaborator](docs/UpdateCloudCollaborator.md)
 - [UpdateCloudWithCloudResource](docs/UpdateCloudWithCloudResource.md)
 - [UpdateCloudWithCloudResourceGCP](docs/UpdateCloudWithCloudResourceGCP.md)
 - [UpdateClusterDns](docs/UpdateClusterDns.md)
 - [UpdateJobQueueRequest](docs/UpdateJobQueueRequest.md)
 - [UpdateMachinePoolRequest](docs/UpdateMachinePoolRequest.md)
 - [UpdateOrganizationCollaborator](docs/UpdateOrganizationCollaborator.md)
 - [UpdatePaymentInfo](docs/UpdatePaymentInfo.md)
 - [UpdatePolicyRequest](docs/UpdatePolicyRequest.md)
 - [UpdateProjectCollaborator](docs/UpdateProjectCollaborator.md)
 - [UpdateResourceQuota](docs/UpdateResourceQuota.md)
 - [UpdateWorkspaceTemplate](docs/UpdateWorkspaceTemplate.md)
 - [UpdatemachinepoolresponseResponse](docs/UpdatemachinepoolresponseResponse.md)
 - [UploadSessionCommandLogsLocations](docs/UploadSessionCommandLogsLocations.md)
 - [UploadsessioncommandlogslocationsResponse](docs/UploadsessioncommandlogslocationsResponse.md)
 - [UpsertResourceTagsRequest](docs/UpsertResourceTagsRequest.md)
 - [UsageByCloud](docs/UsageByCloud.md)
 - [UsageByCluster](docs/UsageByCluster.md)
 - [UsageByClusterType](docs/UsageByClusterType.md)
 - [UsageByInstanceType](docs/UsageByInstanceType.md)
 - [UsageByProject](docs/UsageByProject.md)
 - [UsageByUser](docs/UsageByUser.md)
 - [UsagebycloudListResponse](docs/UsagebycloudListResponse.md)
 - [UsagebyclusterListResponse](docs/UsagebyclusterListResponse.md)
 - [UsagebyclustertypeListResponse](docs/UsagebyclustertypeListResponse.md)
 - [UsagebyinstancetypeListResponse](docs/UsagebyinstancetypeListResponse.md)
 - [UsagebyprojectListResponse](docs/UsagebyprojectListResponse.md)
 - [UsagebyuserListResponse](docs/UsagebyuserListResponse.md)
 - [UseWorkOSResponse](docs/UseWorkOSResponse.md)
 - [UserCloudPermissions](docs/UserCloudPermissions.md)
 - [UserGroup](docs/UserGroup.md)
 - [UserGroupMember](docs/UserGroupMember.md)
 - [UserGroupWithMembers](docs/UserGroupWithMembers.md)
 - [UserInfo](docs/UserInfo.md)
 - [UserMigrationResult](docs/UserMigrationResult.md)
 - [UserResendEmailOptions](docs/UserResendEmailOptions.md)
 - [UserServiceAccessTypes](docs/UserServiceAccessTypes.md)
 - [UserToRemove](docs/UserToRemove.md)
 - [UsergroupListResponse](docs/UsergroupListResponse.md)
 - [UsergroupResponse](docs/UsergroupResponse.md)
 - [UserinfoResponse](docs/UserinfoResponse.md)
 - [UseworkosresponseResponse](docs/UseworkosresponseResponse.md)
 - [UtmFields](docs/UtmFields.md)
 - [ValidateOTPParamsApiModel](docs/ValidateOTPParamsApiModel.md)
 - [ValidationError](docs/ValidationError.md)
 - [ValidationStatus](docs/ValidationStatus.md)
 - [VolumeMetadata](docs/VolumeMetadata.md)
 - [WaitlistStatusResponse](docs/WaitlistStatusResponse.md)
 - [WaitlistStatusType](docs/WaitlistStatusType.md)
 - [WaitliststatusresponseResponse](docs/WaitliststatusresponseResponse.md)
 - [WandBRunDetails](docs/WandBRunDetails.md)
 - [WorkOSAuthorizeUrlResponse](docs/WorkOSAuthorizeUrlResponse.md)
 - [WorkOSEventStatus](docs/WorkOSEventStatus.md)
 - [WorkerNodeType](docs/WorkerNodeType.md)
 - [WorkloadInfo](docs/WorkloadInfo.md)
 - [WorkloadMachineInfo](docs/WorkloadMachineInfo.md)
 - [WorkloadStateInfo](docs/WorkloadStateInfo.md)
 - [WorkloadType](docs/WorkloadType.md)
 - [WorkloadstateinfoListResponse](docs/WorkloadstateinfoListResponse.md)
 - [WorkosauthorizeurlresponseResponse](docs/WorkosauthorizeurlresponseResponse.md)
 - [WorkspaceDataplaneArtifact](docs/WorkspaceDataplaneArtifact.md)
 - [WorkspaceDataplaneArtifacts](docs/WorkspaceDataplaneArtifacts.md)
 - [WorkspaceDataplaneProxiedArtifacts](docs/WorkspaceDataplaneProxiedArtifacts.md)
 - [WorkspaceEvent](docs/WorkspaceEvent.md)
 - [WorkspaceEventFields](docs/WorkspaceEventFields.md)
 - [WorkspaceEventSource](docs/WorkspaceEventSource.md)
 - [WorkspaceEventSourceFilter](docs/WorkspaceEventSourceFilter.md)
 - [WorkspaceReadme](docs/WorkspaceReadme.md)
 - [WorkspaceSnapshotStates](docs/WorkspaceSnapshotStates.md)
 - [WorkspaceSystemArtifacts](docs/WorkspaceSystemArtifacts.md)
 - [WorkspaceTemplate](docs/WorkspaceTemplate.md)
 - [WorkspaceTemplateCategory](docs/WorkspaceTemplateCategory.md)
 - [WorkspaceTemplateClusterEnvironmentMetadata](docs/WorkspaceTemplateClusterEnvironmentMetadata.md)
 - [WorkspaceTemplateComplexity](docs/WorkspaceTemplateComplexity.md)
 - [WorkspaceTemplateIconBackgroundColor](docs/WorkspaceTemplateIconBackgroundColor.md)
 - [WorkspaceTemplateIconType](docs/WorkspaceTemplateIconType.md)
 - [WorkspaceTemplateReadme](docs/WorkspaceTemplateReadme.md)
 - [WorkspaceTemplateVersion](docs/WorkspaceTemplateVersion.md)
 - [WorkspaceTemplateVersionDataObject](docs/WorkspaceTemplateVersionDataObject.md)
 - [WorkspaceTemplatesSortField](docs/WorkspaceTemplatesSortField.md)
 - [WorkspacedataplaneartifactsResponse](docs/WorkspacedataplaneartifactsResponse.md)
 - [WorkspacedataplaneproxiedartifactsResponse](docs/WorkspacedataplaneproxiedartifactsResponse.md)
 - [WorkspaceeventListResponse](docs/WorkspaceeventListResponse.md)
 - [WorkspacereadmeResponse](docs/WorkspacereadmeResponse.md)
 - [WorkspacetemplateListResponse](docs/WorkspacetemplateListResponse.md)
 - [WorkspacetemplateResponse](docs/WorkspacetemplateResponse.md)
 - [WorkspacetemplateclusterenvironmentmetadataResponse](docs/WorkspacetemplateclusterenvironmentmetadataResponse.md)
 - [WorkspacetemplatereadmeResponse](docs/WorkspacetemplatereadmeResponse.md)
 - [WorkspacetemplateversionListResponse](docs/WorkspacetemplateversionListResponse.md)
 - [WorkspacetemplateversionResponse](docs/WorkspacetemplateversionResponse.md)
 - [WriteCloud](docs/WriteCloud.md)
 - [WriteClusterConfig](docs/WriteClusterConfig.md)
 - [WriteProject](docs/WriteProject.md)
 - [WriteSupportRequest](docs/WriteSupportRequest.md)


## Documentation For Authorization

 All endpoints do not require authorization.

## Author




